package PAR::StrippedPARL::Dynamic;
use 5.006;
use strict;
use warnings;
our $VERSION = '0.958';

use base 'PAR::StrippedPARL::Base';

our $Data_Pos = tell DATA;

=head1 NAME

PAR::StrippedPARL::Dynamic - Data package containing a dynamic PARL

=head1 SYNOPSIS

  # For details, see PAR::StrippedPARL::Base.
  PAR::StrippedPARL::Dynamic->write_parl($file) or die "Some error...";

=head1 DESCRIPTION

This class is internal to PAR. Do not use it outside of PAR.

This class is basically just a container for a dynamic binary PAR loader
which doesn't include the PAR code like the F<parl> or F<parl.exe>
you are used to. If you're really curious, I'll tell you it is
just a copy of the F<myldr/par> (or F<myldr/par.exe>) file.

The data is appended during the C<make> phase of the PAR build process,
but only if applicable: If you perl is static, you won't get the dynamic
loader.

If the binary data isn't appended during the build process, the class
methods will return the empty list.

=head1 CLASS METHODS

Inherits the methods from L<PAR::StrippedPARL::Base>.

=cut

sub _data_pos {
    my $class = shift;
    return $Data_Pos;
}

=head1 AUTHORS

Steffen Mueller E<lt>smueller@cpan.orgE<gt>,
Audrey Tang E<lt>cpan@audreyt.orgE<gt>

=head1 COPYRIGHT AND LICENSE

Copyright 2006-2009 by Steffen Mueller E<lt>smueller@cpan.orgE<gt>.

This program is free software; you can redistribute it and/or 
modify it under the same terms as Perl itself.

See L<http://www.perl.com/perl/misc/Artistic.html>

=cut




__DATA__
M?T5,1@$!`0````````````(`*``!````W)X``#0```!8MP```@``!30`(``(
M`"@`'0`<``$``'!8LP``6#,!`%@S`0`(````"`````0````$````!@```#0`
M```T@```-(`````!`````0``!0````0````#````-`$``#2!```T@0``$P``
M`!,````$`````0````$``````````(````"```!DLP``9+,```4`````@```
M`0```&2S``!DLP$`9+,!`)0"``#0$@``!@````"````"````<+,``'"S`0!P
MLP$`(`$``"`!```&````!`````0```!(`0``2($``$B!``!$````1`````0`
M```$````4>5T9```````````````````````````!@````0````O;&EB+VQD
M+6QI;G5X+G-O+C,```0````0`````0```$=.50```````@````8````2````
M!````!0````#````1TY5`)(1F1#!@&=L2-.QR;]B`7'\:#RU80```'P````J
M```````````````-`````````%,```!P`````````&T````D````9````%4`
M```B````!@```%T`````````.````&4```!X````&P```"P````9````<P``
M``0```````````````X````T````'P``````````````#P````,```!,````
M%@```'8```!Q````/0```&$```!0`````````&X`````````:0`````````<
M````"P``````````````.@```&8`````````:```````````````>P```#P`
M```)````=P``````````````2P`````````7```````````````F````````
M`&<````M````$````$(````H````,0``````````````-0```!T````^````
M5@```$T```!$````<@```%H```!?````````````````````-P```$$`````
M````(````!@````E````,````&H````G````````````````````.0```%(`
M````````````````````````(0`````````_````>@```"\`````````````
M``````````````````````````````````(```!C````60```#L`````````
M"@```````````````````'0`````````,@``````````````3@``````````
M`````````!,``````````````$,`````````5```````````````6P``````
M````````7````$D`````````````````````````%0```````````````0``
M`#,```!U````%````%@`````````!0```````````````````",````1````
M`````%X```!K````'@```$````!@```````````````(````!P``````````
M````-@```$8````:`````````%<```````````````````!1`````````&(`
M``!Y````2@`````````2```````````````I```````````````,````;```
M`"L`````````+@``````````````2````$\`````````10``````````````
M``````````!O````````````````````1P```&$````#````(`````H```"@
M$@`(`D81H<````!6`'$8P@@`/`T`%1$``!`"`"@`````````6")@"@0*`$2$
M!ZA`"$5@20"$`3Y"/)<``0`((5"`)`E@#)-X0$1:`$``0``!``(;`4"`C,"$
M``(0D!"+"0`(`1"0B4!`PDF`+$"8`$``(``@!`F`E('LCI=62`,`````````
M!`````4````'``````````````````````````@````*````#`````X`````
M````#P```!$````5`````````!<`````````&````!D````=````'P```",`
M```D````)0```"<`````````*````"D````M`````````"X````O````,```
M`#$````R````-````#4`````````.0```#H`````````/@``````````````
M/P```$````!!`````````$(```!#````10```$@```!+`````````$X```!/
M````4````%$```````````````````!4`````````````````````````%8`
M``!7`````````%D`````````6P```%T```!>````7P```&``````````80``
M`&(```!F`````````&@`````````:@````````!L````;@````````!P````
M<0```'(```!S````=````'@```!?EI,<HUKOD%;;DQS#CH?_#3J7"])1!(2!
M=((->O!*:WU!CL5V5#R4S3\,K_<CSB#49-1\(72P`N!2=R@N3CWV9J_,9MOW
M`%X&I(?_`:\TZ+%(G>=39B&:X*<""LY*KO\^^?^\S]Y'+>)'Q@$Y0`RO;'.%
MQ>P_D`+&#N`]/WZ6?#5O3M[%B0608)CO$F=)22(!(_FDG;N3''SM$0^@DFAG
MAOF<@4-%U>Q;FCL/04V=?'&$,(0M5>O6I]VC:UCOEWFC`&6O.?*+'`P4XIZB
M`O89VLWCG@4RI87[H6Q@,F+;[>K3[P[(.4`?N8WQ#NG[P\+MWI,<K4OCP-EQ
M6!PKT.$B+`ZQ<QN?UKU8.T`?VE])(</E/RR8(M1HNN.2?"'_Y`Z*F-W";GII
M^HO9-5>3K01B-^/PP4/R[\CF[U][WH4@3YOH?!C>ZR(53UIHR<6YG$`PN((-
M41M]7[(!BV^_VE<;=F_C<+W02WUK"4/6(6)D!U.I!Y`=`A!1"P^UI7ZIG)MB
MT/J"["SVBVM_FGS0GRS\A_"6?.X+4?GSV],=D'6"#4-F2Q!>7W9@!6RRS1;J
M6O$]K3D-*?P-J*/@^TE7DEI2_=+O#RS?_DANQ=\?H"(+('V0$.DNQ9NVR-6R
M<=ZKRI]'F`7&`````````````````````!$``````````````"`````@````
M```````````@````+@0``)2>````````$@````D#``!0G0```````!(```"P
M`P``\)P````````2````E`,``-2=````````$@```'H%``#DM0$``````"``
M&`!Z`@``3)L````````2````C0,``'R>````````$@```&H"``!LG```````
M`!(```"Q!0``7*\``$0````2``X`K`0``/BU`0``````$`#Q_S\#```HG@``
M`````!(```!R`P``J)P````````2````_`0``-#(``#@`P``$@`.`-<#```L
MG0```````!(```"Q````$)L````````2````-00``%B;````````$@```#8%
M``"<N```,`$``!(`#@!0`P``%)T````````2````]@,```R<````````$@``
M`+L$```TQ@$``````!``\?]0`0``^)T````````2````?P0``%@S`0``````
M$`#Q_R`%```LLP``S````!(`#@!4!0``P)P````````2````#00``#B=````
M````$@```.$%``#0O@````H``!(`#@#?!```E)\``$0````2``X`60,``*";
M````````$@```,0#```$G@```````!(```!#`@``-)X````````2````?P,`
M`$">````````$@```#(#``"@G@```````!(```"``0``E)L````````2````
M2`0``/BU`0`$````(0`9`/$"``#8G````````!(```#A`P``()T````````2
M````^`(``*R>````````$@```*(#``"<G````````!(```"'`P``-)L`````
M```2````C0$``'R;````````$@```*````!XG````````!(```"9!```^+4!
M```````0`/'_ZP(``/R<````````$@```!$#```PG````````!(````=`0``
M$)X````````2````_@$``,B=````````$@```$D$``#XM0$`!````"$`&0#&
M!```-,8!```````0`/'_[````(R=````````$@```.\#```(M@$`!````!$`
M&0#L!```>,T```0````2``X`'`(``,2;````````$@```(T%``!\S0``<```
M`!(`#@!.`@``")T````````2````[@4``-BU```(`0``$@`.`'X%``#<G@``
M`````!(`#@#V!```3-,````````2``\`80,``&B=````````$@```(<%``#L
MF@```````!(`#`#7````O)T````````2````FP,``'2=````````$@```&D%
M``!8TP``!````!$`$`"@!```^+4!```````0`/'_%00``!R>````````$@``
M`#0```!@G````````!(````?!```I)T````````2````70$``(2<````````
M$@```(T$``!@,P$``````!``\?^%!0``L,P``#@````2``X`H0$``"B;````
M````$@```)0$```TQ@$``````!``\?\`!@``O+P``!0"```2``X`_0```+B;
M````````$@```"`#``"PG0```````!(```!X````Q)X````````2````UP(`
M`#R<````````$@```%P"``#DG````````!(````+`0``T)X````````2````
MH@4``&37``#J6P``$0`0`$$!``#,G````````!(```!C````<)X````````2
M````Z@$```"<````````$@```$(```"8G0```````!(```!'!```^+4!``0`
M```1`!D`J0,``-";````````$@```,H!``#<FP```````!(````2!0``O*T`
M`%P````2``X`N@0``#3&`0``````$`#Q_\\#``!`FP```````!(```#(````
MD)P````````2````>`4``.2U`0``````$``8`%\$````M@$`!````!$`&0!N
M`0``B)L````````2````CP```(B>````````$@```#<#``"XG@```````!(`
M``!"!0``@+@``!P````2``X`F`(``/2;````````$@```(4"``#@G0``````
M`!(```!"!```8+H``%P"```2``X`!@0``.B;````````$@```*8!```DG```
M`````!(```#]`P``[)T````````2````HP(```RV`0`3````$0`9`+T#``"T
MG````````!(```"W`P``@)T````````2````+P$``%2<````````$@```$<#
M``!DG@```````!(````G!```2)P````````2````D0(``%R=````````$@``
M`-@!``!8G@```````!(````-!@``X+8``*`!```2``X`JP$``$2=````````
M$@```'D#```<FP```````!(````L`@``K)L````````2````704``,RY``"4
M````$@`.`,T%``#TM0$`!````!$`&`!4````3)X````````2````S@0``/BS
M```$````$@`.`+<!``!DFP```````!(````U`@``&)P````````2````G04`
M`/"U`0`$````$0`8``!L:6)P97)L+G-O+C4N,3``7U]G;6]N7W-T87)T7U\`
M7TIV7U)E9VES=&5R0VQA<W-E<P!097)L7W-Y<U]T97)M`%!E<FQ?27-T871B
M=69?<'1R`%!E<FQ?<WES7VEN:70S`%!E<FQ?265X:71?9FQA9W-?<'1R`%!E
M<FQ?<V%V95]D97-T<G5C=&]R7W@`4&5R;%])8V]M<&-V7W!T<@!097)L7V%T
M9F]R:U]L;V-K`%!E<FQ?26-U<G-T86-K:6YF;U]P='(`<&5R;%]C;VYS=')U
M8W0`4&5R;%]C<F]A:U]N;V-O;G1E>'0`4&5R;%])<&%R<V5R7W!T<@!097)L
M7V%V7W-H:69T`%!E<FQ?<W9?,G!V7V9L86=S`%!E<FQ?271O<%]E;G9?<'1R
M`%!E<FQ?271A:6YT961?<'1R`%!E<FQ?<W9?<V5T<'9N`%!E<FQ?;F5W4U9P
M=@!097)L7VYE=UA37V9L86=S`%!E<FQ?26EN7V5V86Q?<'1R`%!E<FQ?26]P
M7W!T<@!097)L7TEE=F%L7W)O;W1?<'1R`'!E<FQ?9G)E90!097)L7VUG7W-E
M=`!097)L7V%T9F]R:U]U;FQO8VL`4&5R;%]S=E]S971P=@!097)L7T=T:')?
M:V5Y7W!T<@!097)L7T=D;U]U;F1U;7!?<'1R`%!E<FQ?27!E<FQ?9&5S=')U
M8W1?;&5V96Q?<'1R`%!E<FQ?9W9?9F5T8VAP=@!P97)L7W)U;@!097)L7V1O
M=6YW:6YD`%!E<FQ?;F5W6%,`<&5R;%]D97-T<G5C=`!097)L7V%V7V9E=&-H
M`&)O;W1?1'EN84QO861E<@!P97)L7W!A<G-E`%!E<FQ?<V%F97-Y<VUA;&QO
M8P!P97)L7V%L;&]C`%!,7VUE;6]R>5]W<F%P`&QI8F1L+G-O+C(`;&EB;2YS
M;RXV`&QI8G!T:')E860N<V\N,`!P=&AR96%D7V=E='-P96-I9FEC`&-L;W-E
M`&]P96XV-`!?7V5R<FYO7VQO8V%T:6]N`&QS965K-C0`<F5A9`!L:6)C+G-O
M+C8`7U]R96=I<W1E<E]A=&9O<FL`97AI=`!S<')I;G1F`'-T<FYC;7``7U]S
M=')D=7``8VQO<V5D:7(`<W1R;F-P>0!?7W-T86-K7V-H:U]F86EL`'5N;&EN
M:P!M:V1I<@!R96%L;&]C`&%B;W)T`&UE;6-H<@!G971P:60`<W1R=&]K`'-T
M<FQE;@!M96US970`<W1R<W1R`')M9&ER`&UE;6-P>0!?7VQX<W1A=#8T`&]P
M96YD:7(`7U]X<W1A=#8T`%]?8W1Y<&5?8E]L;V,`<W1D97)R`&=E='5I9`!R
M96%D;&EN:P!E>&5C=G``9G!R:6YT9@!R96%D9&ER-C0`;65M;6]V90!A8V-E
M<W,`<W1R8VUP`%]?;&EB8U]S=&%R=%]M86EN`%]?96YV:7)O;@!L9"UL:6YU
M>"YS;RXS`%]?<W1A8VM?8VAK7V=U87)D`&QI8F-R>7!T+G-O+C$`7U]E>&ED
M>%]S=&%R=`!?7V5X:61X7V5N9`!?961A=&$`7U]B<W-?<W1A<G0`7U]B<W-?
M<W1A<G1?7P!?7V)S<U]E;F1?7P!?7V5N9%]?`'!A<E]C=7)R96YT7V5X96,`
M<&%R7V)A<V5N86UE`%]?;&EB8U]C<W5?9FEN:0!84U]);G1E<FYA;'-?4$%2
M7T)/3U0`<&%R7V5N=E]C;&5A;@!P87)?8W5R<F5N=%]E>&5C7W!R;V,`<&%R
M7V1I<FYA;64`9V5T7W5S97)N86UE7V9R;VU?9V5T<'=U:60`<&%R7V-L96%N
M=7``7TE/7W-T9&EN7W5S960`7U]D871A7W-T87)T`'AS7VEN:70`7U]L:6)C
M7V-S=5]I;FET`&YA;65?;&]A9%]M>5]P87)?<&P`6%-?26YT97)N86QS7U!!
M4E]#3$5!4E-404-+`'-I>F5?;&]A9%]M>5]P87)?<&P`<&%R7VUK=&UP9&ER
M`'!A<E]S971U<%]L:6)P871H`'!A<E]F:6YD<')O9P!P87)?:6YI=%]E;G8`
M1TQ)0D-?,BXT``````````(``P`"``(``0````(````!``$``@`"``$``@``
M``(``0`"``(``0````$``0`"``(``0`!``(``@````(``@````(``P`"``,`
M`@`"```````!``,``P```````@`!`````@`!`````0````$``0`!``(``0``
M``(``0`!``(````"`````0`!`````0`!`````@````,```````$`````````
M```"``(````!``$``@````$`!````````@`!```````!``(``@`"`````@`"
M`````@`"``(````!`````@````$``0````$```````$``0`!`%$$```0````
M(````!1I:0T```0`&@8````````!``$`QP(``!`````@````%&EI#0```P`:
M!@````````$``0`6`P``$``````````4:6D-```"`!H&````````X+4!`!4!
M``#XM0$`%%8```"V`0`47@``"+8!`!0T```,M@$`%&D``)RT`0`6$0``H+0!
M`!9S``"DM`$`%D@``*BT`0`6*0``K+0!`!9;``"PM`$`%@@``+2T`0`6$@``
MN+0!`!9Y``"\M`$`%@$``,"T`0`6*@``Q+0!`!9?``#(M`$`%B,``,RT`0`6
M'@``T+0!`!9T``#4M`$`%DL``-BT`0`6-@``W+0!`!97``#@M`$`%E@``.2T
M`0`69@``Z+0!`!9C``#LM`$`%E0``/"T`0`6%0``]+0!`!9Z``#XM`$`%F<`
M`/RT`0`6+@```+4!`!9.```$M0$`%FX```BU`0`6;```#+4!`!9#```0M0$`
M%@H``!2U`0`6*P``&+4!`!9%```<M0$`%EP``""U`0`6*```)+4!`!8.```H
MM0$`%FH``"RU`0`6&@``,+4!`!92```TM0$`%B4``#BU`0`63P``/+4!`!8%
M``!`M0$`%BT``$2U`0`6.```2+4!`!84``!,M0$`%B8``%"U`0`6$```5+4!
M`!8;``!8M0$`%G(``%RU`0`6!```8+4!`!9O``!DM0$`%CP``&BU`0`6/P``
M;+4!`!9K``!PM0$`%C,``'2U`0`650``>+4!`!9$``!\M0$`%DP``("U`0`6
M/@``A+4!`!8P``"(M0$`%@8``(RU`0`69```D+4!`!9H``"4M0$`%A<``)BU
M`0`6'P``G+4!`!8O``"@M0$`%D(``*2U`0`6#0``J+4!`!8@``"LM0$`%B$`
M`+"U`0`6=P``M+4!`!9P``"XM0$`%FT``+RU`0`64P``P+4!`!8)``#$M0$`
M%F```,BU`0`6`P``S+4!`!8B``#0M0$`%B<``-2U`0`680``V+4!`!9-``#<
MM0$`%E```!!`+>D(`0#K$$"]Z![_+^$$X"WE!."?Y0[@C^`(\+[EA!D!``#&
MC^(1RHSBA/F\Y0#&C^(1RHSB?/F\Y0#&C^(1RHSB=/F\Y0#&C^(1RHSB;/F\
MY0#&C^(1RHSB9/F\Y0#&C^(1RHSB7/F\Y0#&C^(1RHSB5/F\Y0#&C^(1RHSB
M3/F\Y0#&C^(1RHSB1/F\Y0#&C^(1RHSB//F\Y0#&C^(1RHSB-/F\Y0#&C^(1
MRHSB+/F\Y0#&C^(1RHSB)/F\Y0#&C^(1RHSB'/F\Y0#&C^(1RHSB%/F\Y0#&
MC^(1RHSB#/F\Y0#&C^(1RHSB!/F\Y0#&C^(1RHSB_/B\Y0#&C^(1RHSB]/B\
MY0#&C^(1RHSB[/B\Y0#&C^(1RHSBY/B\Y0#&C^(1RHSBW/B\Y0#&C^(1RHSB
MU/B\Y0#&C^(1RHSBS/B\Y0#&C^(1RHSBQ/B\Y0#&C^(1RHSBO/B\Y0#&C^(1
MRHSBM/B\Y0#&C^(1RHSBK/B\Y0#&C^(1RHSBI/B\Y0#&C^(1RHSBG/B\Y0#&
MC^(1RHSBE/B\Y0#&C^(1RHSBC/B\Y0#&C^(1RHSBA/B\Y0#&C^(1RHSB?/B\
MY0#&C^(1RHSB=/B\Y0#&C^(1RHSB;/B\Y0#&C^(1RHSB9/B\Y0#&C^(1RHSB
M7/B\Y0#&C^(1RHSB5/B\Y0#&C^(1RHSB3/B\Y0#&C^(1RHSB1/B\Y0#&C^(1
MRHSB//B\Y0#&C^(1RHSB-/B\Y0#&C^(1RHSB+/B\Y0#&C^(1RHSB)/B\Y0#&
MC^(1RHSB'/B\Y0#&C^(1RHSB%/B\Y0#&C^(1RHSB#/B\Y0#&C^(1RHSB!/B\
MY0#&C^(1RHSB_/>\Y0#&C^(1RHSB]/>\Y0#&C^(1RHSB[/>\Y0#&C^(1RHSB
MY/>\Y0#&C^(1RHSBW/>\Y0#&C^(1RHSBU/>\Y0#&C^(1RHSBS/>\Y0#&C^(1
MRHSBQ/>\Y0#&C^(1RHSBO/>\Y0#&C^(1RHSBM/>\Y0#&C^(1RHSBK/>\Y0#&
MC^(1RHSBI/>\Y0#&C^(1RHSBG/>\Y0#&C^(1RHSBE/>\Y0#&C^(1RHSBC/>\
MY0#&C^(1RHSBA/>\Y0#&C^(1RHSB?/>\Y0#&C^(1RHSB=/>\Y0#&C^(1RHSB
M;/>\Y0#&C^(1RHSB9/>\Y0#&C^(1RHSB7/>\Y0#&C^(1RHSB5/>\Y0#&C^(1
MRHSB3/>\Y0#&C^(1RHSB1/>\Y0#&C^(1RHSB//>\Y0#&C^(1RHSB-/>\Y0#&
MC^(1RHSB+/>\Y0#&C^(1RHSB)/>\Y0#&C^(1RHSB'/>\Y0#&C^(1RHSB%/>\
MY0#&C^(1RHSB#/>\Y0#&C^(1RHSB!/>\Y0"PH.,`X*#C!!"=Y`T@H.$$("WE
M!``MY1#`G^4$P"WE#`"?Y0PPG^43___K"?__ZWC-``!@N@``?,T``!PPG^4<
M()_E`S"/X`(@D^<00"WI``!2XP[__QL00+WH'O\OX6@5`0!0`0``$#"?Y0`@
MT^4``%+C`2"@`P`@PP4>_R_A'[8!`"0`G^400"WI`#"0Y0``4^,#```*%#"?
MY0``4^,/X*`1$_\O$1!`O>@>_R_A;+,!````````,-#E``!3XP`0H`$)```*
M`!"@X0$@@.(@`)_E``"0Y0``T.4``%/A`A"@`0$PTN0``%/C^O__&@$`H.$>
M_R_A7-,``/`/+>D%W4WB'%"`X@`@H.,-,*#A`A"5YP%,H.$!Q*#A(4R$X?_(
M#.(A%*#A#,"$X?\<`>(!$(SA`A"#YP0@@N)``%+C\O__&DU/@^(T,(/B%!`3
MY0`@D^4LP!/E`B`AX#00$^4,("+@`2`BX.(OH.$,((/E!#"#X@0`4^'S__\:
M$!"0Y0`@G>4@!)#I#("0Y63,G^4$<)WE`#"0Y0(@@>`'<(C@#!"@X06`R.$,
MP(+@!2`*X&5!H.'CS8S@`B"(X0$0A^`(<)WE`B",X`-@RN$#4`3@(,R?Y050
MAN$'<(K@!1"!X`Q@H.$,P(?@#'"=Y>(=@>!B4:#A8X&@X0*0Q.$!H,CA!F"'
MX`@@`N`%<`'@!$"&X`=PBN'AS8S@`B")X0(@C.#0JY_E!\"$X!!`G>5A<:#A
M%!"=Y>+-C.`*8*#A"J"$X&)!H.$&8('@"("*X`00#.`,H,?A`I#%X0$0BN$%
M4(;@!R`"X.R-B.`"((GAA*N?Y0$0A>`84)WE`B"(X&R!H.$<P)WEXAV!X`I@
MH.$*H(7@8E&@X09@C.`'<(K@!<`!X`&@R.$"D,3A#,"*X01`AN`((`+@X7V'
MX`(@B>$TJY_E#,"$X"!`G>4"((?@87&@X200G>7BS8S@"F"@X0J@A.!B0:#A
M!F"!X`B`BN`$$`S@#*#'X0*0Q>$!$(KA!5"&X`<@`N#LC8C@`B")X>2JG^4!
M$(7@*%"=Y0(@B.!L@:#A+,"=Y>(=@>`*8*#A"J"%X&)1H.$&8(S@!W"*X`7`
M`>`!H,CA`I#$X0S`BN$$0(;@""`"X.%]A^`"((GAE*J?Y0S`A.`P0)WE`B"'
MX&%QH.$T$)WEXLV,X`I@H.$*H(3@8D&@X0*0Q>$&8('@"("*X`00#.`,H,?A
M!R`"X`50AN#LC8C@.&"=Y0(@B>$!$(KA0*J?Y0(@B.`!$(7@;(&@X3S`G>7B
M'8'@"E"@X0J@AN!B8:#A!5",X`=PBN`&P`'@`:#(X0*0Q.$,P(KA!$"%X`@@
M`N#\J9_E#,"$X$!`G>7A?8?@`B")X0(@A^`*<*#A"J"$X&%!H.%$$)WEXLV,
MX&)1H.$"D,;A!W"!X`B`BN`%$`S@#*#$X00@`N`"((GA!F"'X`$0BN'LC8C@
M`J"(X*"YG^4!((;@2!"=Y6S!H.$+8*#A"["!X.HM@N!J$:#A"I#%X02PB^`,
MH`K@3$"=Y0*`S.$!<`+@"J")X6*1H.'B+8O@"J""X`9@A.!0()WE5$F?Y050
MAN`$0(+@`6`IX`=PB.$,P(3@"B`FX`=0A>`TN9_E`B",X%3`G>7JC87@:E&@
MX0M@H.$+L(S@"<`EX&AQH.'H+8+@"(`LX%C`G>4%H"?@!F",X`E@AN`"0"K@
M`1"+X`1`AN#LR)_E7&"=Y0B`@>!B$:#A!Z`AX.(MB.`,P(;@XDV$X`5@C.!B
MP:#A`B`JX,"(G^4"((;@8&"=Y0&@+.`(4*#A"("&X.0M@N!D8:#A!W"(X`2`
M*N!D0)WE#*`FX`APA^`%4(3@:("=Y81(G^4"H"K@`5"%X&(1H.$$0(C@XBV'
MX`I0A>`&H"'@XEV%X`QPA.!BP:#A`B`JX%2(G^4"((?@;'"=Y0&@+.`(0*#A
M"("'X.4M@N!E<:#A!F"(X`6`*N!P4)WE#*`GX`A@AN`$0(7@=("=Y1A8G^4"
MH"K@`4"$X&(1H.$%4(C@XBV&X`I`A.`'H"'@XDV$X`Q@A>!BP:#A`B`JX.B'
MG^4"((;@>&"=Y0A0H.$(@(;@!W"(X'R`G>4!H"S@9&&@X050B.`$@"K@Y"V"
MX`R@)N`(<(?@L$>?Y8"`G>4"H"K@`5"%X&(1H.$$0(C@XBV'X`I0A>`&H"'@
MXEV%X`QPA.!BP:#A`B`JX'R'G^4"((?@A'"=Y0A`H.$(@(?@!F"(X(B`G>4!
MH"S@97&@X01`B.`%@"K@Y2V"X`R@)^`(8(;@1%>?Y8R`G>4"H"K@`4"$X&(1
MH.$*0(3@XBV&X`50B.`'8"'@XDV$X`Q0A>!BP:#A`B`FX!"'G^4"((7@D%"=
MY0A@H.$(@(7@!W"(X)2`G>4!H"S@9%&@X09@B.`$@"K@Y"V"X`R@)>`(<(?@
MV$:?Y9B`G>4"H"K@`1"&X&)AH.$$0(C@XBV'X`6`)N`*$('@XAV!X`S`A.!B
M0:#A`B`HX`(@C."@=I_EG,"=Y0:@).`'<(S@X2V"X&'!H.$%4(?@`1`JX`%0
MA>"`AI_EH!"=Y020C.'B787@"("!X`*0">!B$:#A9':?Y:0@G>4$H`S@#+"!
MX09@B.`'<(+@"H")X06P"^`,D`'@!$"'X`F@B^%E(:#A"("&X`J@A.`L9I_E
MJ$"=Y>5=B.`!<(+A!;`'X`&0`N`&8(3@#,"&X`F`B^%E0:#A"(",X`!VG^6L
MP)WEY5V*X`)@A.$%L`;@`I`$X`=PC.`!$(?@":"+X67!H.$*H('@U&6?Y;`0
MG>7E78C@!'",X06P!^`$D`S@!F"!X`(@AN`)@(OA91&@X0B`@N"H=9_EM""=
MY>5=BN`,8('A!;`&X`R0`>`'<(+@!$"'X`F@B^%E(:#A"J"$X'QEG^6X0)WE
MY5V(X`%P@N$%L`?@`9`"X`9@A.`,P(;@"8"+X65!H.$(@(S@4'6?Y;S`G>7E
M78K@`F"$X06P!N`"D`3@!W",X`$0A^`)H(OA9<&@X0J@@>`D99_EP!"=Y>5=
MB.`$<(SA!;`'X`20#.`&8('@`B"&X`F`B^%E$:#A"(""X/ATG^7$()WEY5V*
MX`Q@@>$%L`;@#)`!X`=P@N`$0(?@":"+X64AH.$*H(3@S&2?Y<A`G>7E78C@
M`7""X06P!^`!D`+@!F"$X`S`AN`)@(OA94&@X0B`C."@=)_ES,"=Y>5=BN`"
M8(3A!;`&X`*0!.`'<(S@`1"'X`F@B^%EP:#A"J"!X'1DG^70$)WEY5V(X`1P
MC.$%L`?@!)`,X`9@@>`"((;@"8"+X641H.$(@(+@2'2?Y=0@G>7E78K@#&"!
MX06P!N`,D`'@!W""X`1`A^`)H(OA92&@X0J@A.`<9)_EV$"=Y>5=B.`!<(+A
M!;`'X`&0`N`&8(3@#,"&X`F`B^%E0:#A"(",X/!SG^7<P)WEY5V*X`)@A.$%
MD`;@`J`$X`=PC.`!$(?@"G")X67!H.$'<('@Q&.?Y>`0G>7E78C@!(",X060
M".`$H`S@!F"!X`(@AN`*8(GA91&@X09@@N"8@Y_EY""=Y>5=A^`,<('A!9`'
MX`R@`>`(@(+@!$"(X`J`B>%E(:#A"("$X&QSG^7H0)WEY6V&X`%0@N$!H`+@
M!I`%X`=PA.`,<(?@"I")X69!H.'FS8C@0%.?Y0E@A^#L<)WE`J"$X050A^`,
MH`K@`H`$X`$0A>`(@(KA('.?Y0B`@>#P$)WE[&V&X`>@H.%LP:#A!W"!X/00
MG>5F4:#A!)`LX.:-B.`*H('@!F`IX`RP)>`"((?@!B""X`1`BN#X8)WE"+`K
MX-1RG^5H$:#A"T"$X.B-@N#HG83@!W"&X/Q`G>6X8I_E!:`AX`S`A^`&<*#A
M!F"$X&@AH.$%4(;@"(`JX`!AG>5I0:#A",",X.G-C.`'<(;@`F`DX`&`(N`,
M8";@`7"'X`F`*.`&<(?@;**?Y01AG>5L$:#A"%"%X.S-A>`*H(;@!%`AX.Q]
MA^`"H(K@2&*?Y6PAH.$,P"7@"%&=Y0:`H.$&8(7@!$"&X`QAG>5G4:#A#,"*
MX`&0(N#GS8S@"("&X`)@)>`'<"G@`8"(X`Q@)N`'0(3@`**?Y09PB.`089WE
M;!&@X0J@AN#LS83@!4`AX.Q]A^`"H(K@W&&?Y6PAH.$,P"3@%$&=Y0:`H.$&
M8(3@!5"&X!AAG>5G0:#A#,"*X`&0(N#GS8S@"("&X`)@).`'<"G@`8"(X`Q@
M)N`'4(7@E*&?Y09PB.`<89WE;!&@X0J@AN#LS87@!%`AX.Q]A^`"H(K@<&&?
MY6PAH.$,P"7@(%&=Y0:`H.$&8(7@!$"&X"1AG>5G4:#A#,"*X`&0(N#GS8S@
M"("&X`)@)>`'<"G@`8"(X`Q@)N`'0(3@**&?Y09PB.`H89WE;!&@X0J@AN#L
MS83@!4`AX.Q]A^`"H(K@!&&?Y6PAH.$,P"3@+$&=Y0:`H.$&8(3@!5"&X#!A
MG>5G0:#A`9`BX`S`BN#GS8S@`J`DX`B`AN`'<"G@!U"%X`&`B.`,<"K@!W"(
MX+A@G^4T@9WE;!&@X09@B.#LS87@!(`AX`R`*.`"8(;@F%"?Y0A@AN`X@9WE
M['V'X&PAH.$%P*#A!5"(X#R!G>4!H"+@"#"#X&>!H.'G;8;@#,"#X`1`A>`"
M,"C@!W`JX`8P(^`'0(3@`1",X`,0@>#F/83@,`"0Z0/`A.`,H)#E$$"0Y69A
MA>`(@(K@`B"$X.,]@>``,(#E$""`Y03`@.4(8(#E#("`Y07=C>+P#[WH'O\O
MX9EY@EJAZ]ENW+P;C];!8LKP1RWI`'!0X@&@H.$"```:``"@X_!'O>@>_R_A
ME#"?Y0"`D^4``%CC^/__"@!@U^4]`%;C``!6$P!@H`,!8*`3!0``"@=@H.$!
M,/;E/0!3XP``4Q/[__\:!F!GX`!`F.4``%3CZ?__"@A0H.$$`*#A!Q"@X08@
MH.$Q_/_K``!0XP(``!H&,-3G/0!3XP,```H$0+7E``!4X_/__QK;___J!5!H
MX$51H.$!`(;B`%"*Y0``A.#6___J^+4!``3@+>4,T$WB!!"-XLS__^L,T(WB
M!."=Y![_+^$00"WI2$"?Y0``E.4!`'#C`0``"A!`O>@>_R_A-`"?Y>___^L`
M`%#C!@``"@``T.4``%#C`P``"C``4.(!`*`3``"$Y?+__^H``*#C``"$Y>__
M_^KLM0$`U-,``'!`+>D(T$WB`%"@X01`C>(\8)_E!@``Z@`PEN4$()WE`C&#
MX`0@L^4``%+C!"`#Y?O__QH%`*#A!!"@X:+__^L``%#C\___&@C0C>)P0+WH
M'O\OX?BU`0#P02WI`=I-X@C03>+,0)_E"%"-X@`PE.4$4$7B`<J-X@%PH.$"
M@*#AM`"?Y040H.&P()_E!#",Y<_[_^L``%#C'0``V@%@0.(&,-7G``!3XP!@
MH!$6```*!0"@X2\0H.,&(*#AZ/O_ZP``4.,2```*``"@X]O[_^L``)#E4OO_
MZP<0H.$%(*#A!C"@X7+[_^L!.HWB!""3Y0`PE.4#`%+A#0``&@C0C>(!VHWB
M\$&]Z![_+^$``%;CYO__&@``H./(^__K``"0Y3_[_^L'$*#A"""@X23[_^OL
M___JA?O_ZP"V`0#@TP``_P\``!!`+>D``*#CN_O_ZP``D.4R^__K`!#@XR?[
M_^L``*#CM?O_ZP``D.4L^__K#!"?Y0`@H./+^__K$$"]Z![_+^&@KP``$$`M
MZ0``H..J^__K``"0Y2'[_^O5^O_K`#"0Y0``H.,$0)/EH_O_ZP``D.4:^__K
M[/K_ZP`PT.4``*#C&##$Y9S[_^L``)#E$_O_Z\?Z_^L`,)#E``"@XP1`D^65
M^__K``"0Y0S[_^OA^O_K`#"0Y0``H..P,=/A_CS#X[HQQ.&,^__K``"0Y0/[
M_^NW^O_K`#"0Y0``H.,$0)/EA?O_ZP``D.7\^O_K(!&?Y0`@H.-H^__K'`"$
MY0``H.-]^__K``"0Y?3Z_^NH^O_K`#"0Y0``H.,$0)/E=OO_ZP``D.7M^O_K
MO/K_ZP`PD.4``*#C(#"$Y6_[_^L``)#EYOK_ZYKZ_^L`,)#E``"@XP1`D^5H
M^__K``"0Y=_Z_^LR^__K`#"0Y0``4^,&```*``"@XV#[_^L``)#EU_K_ZRK[
M_^L`,)#E;#"3Y20PA.4``*#C6/O_ZP``D.7/^O_K@_K_ZP`PD.4`0*#C!#"3
MY00`H.$H0(/E3_O_ZP``D.7&^O_K>OK_ZP`PD.4$`*#A!#"3Y2Q`@^5'^__K
M``"0Y;[Z_^MR^O_K`#"0Y00`H.$$0)/E0/O_ZP``D.6W^O_K*_O_ZP`PD.4P
M,(3E$$"]Z![_+^$0U0``\$$MZ0!`4.)HT$WB`@``"@`PU.4``%/C`@``&FC0
MC>+P0;WH'O\OX6?Z_^L`4%#B#7"@$?C__PH%`*#A&?O_ZP"`4.($`*#A(@``
M"A,PV.43@(CB+@!3XR,```JQ^O_K`&"@X0@`H.&N^O_K``"&X`(`@.+;^O_K
M"#"@X0!@H.$$(*#AC!"?Y2W[_^L&$*#A#2"@X0,`H./&^O_K`0!PXP8`H.$#
M```*$#"=Y0\Z`^(!"5/C%0``"IWZ_^L&`*#A>OK_ZP4`H.'V^O_K`(!0X@0`
MH.'<__\:!0"@X:_Z_^L$`*#AR/K_Z\O__^H!,-CE``!3X\___PHN`%/CUO__
M&@(PV.4``%/CRO__"M+__^JZ___KZ/__ZO#3``!P0"WI`$"@X0``H./M^O_K
M``"0Y63Z_^NZ^O_K!!"@X0`@H.$#`*#CT?K_ZP!04.("```*``"@XW!`O>@>
M_R_AX/K_ZP``D.57^O_KK?K_ZQ`PD.4/.@/B`0E3XP@```H%`*#AU_K_ZP``
MD.5.^O_KI/K_ZQ`PD.4/.@/B"@I3X^O__QH$`*#A`A"@XTGZ_^L!`'#B``"@
M,^;__^KP0"WIM%"?Y0+:3>(4T$WB`#"5Y0(JC>(,,(+EH?K_ZP%*C>(00(3B
M"$!$X@`@H.&,$)_E!`"@X8@PG^72^O_K``!0XPH``*H`0*#C`CJ-X@P@D^4`
M,)7E!`"@X0,`4N$5```:%-"-X@+:C>+P0+WH'O\OX1!@C>(,8$;B!`"@X080
MH.$!*J#CC/K_ZP!P4.+L__^Z`0"'XF3Z_^L`0%#BZ?__"@80H.$'(*#A-?K_
MZP`PH.,',,3GX___ZE[Z_^L`M@$`^-,```34``#+___J\$<MZ0`PT>4!0*#A
M/0!3XP%`@0((T$WB`&"@X00`H.$>^O_K!!"-X@!PH.$&`*#A+/[_ZP!04.(,
M```*%_K_ZP``5^$`,*"370``B@,@U.<``%+C`R#%YP$P@^+Z__\:``"@XPC0
MC>+P1[WH'O\OX5R!G^4``)CE`#"0Y0``4^,#4*`!"!"@`P4```H!4(7B!3&0
MYP``4^/[__\:`A"%X@$1H.$L,9_E`""3Y0``4N,'```*8OK_ZP``4.,`H*#A
M``"(Y061H!$,```:``#@X^/__^H!(*#C`0"@X0`@@^4>^O_K`*!0XO?__PH%
MD:#A`!"8Y0D@H.$J^O_K`*"(Y0$PA>(`(*#C`R&*YP10C>4`,-;E/0!3XP``
M4Q,`,*`#`3"@$P,@H`$%```*!B"@X0$P\N4]`%/C``!3$_O__QH"(&;@`@"'
MX@(`@.``4)CE`OK_ZP``4.,)`(7GVO__"FPPG^4$$)WE`""3Y0`PUN4!(9+G
M``!3XP`PPN4%```:!@``Z@$PUN4!8(;B``!3XP$PXN4!```*/0!3X_C__QH]
M,*#C`##"Y0`PH.,#$-3G`3"#X@``4>,!$.+E^O__&J;__^H$D)WE!("?Y0F1
MH.'.___J^+4!`""V`0#P1RWI],"?Y2#03>((4(WB!$",X@5@H.$`<*#A#P"T
MZ`\`IN@#`)3H`P"&Z`A`G>4`,-3E``!3XQ<```H<H)SE!@``ZK/Y_^L``%#C
M%0``"@1`M>4`,-3E``!3XPX```H$`*#AU_W_ZP!@4.('$*#A`@``"@`PUN4`
M`%/C\/__&@0`H.$'$*#A9?__ZP1`M>4`,-3E``!3X_#__QH@T(WB\$>]Z![_
M+^$'`*#AA/G_ZP"0H.$*`*#A@?G_ZP"`H.$&`*#A?OG_ZPB`B>`!@(CB``"(
MX*KY_^LD$)_E`("@X0<@H.$*,*#A`&"-Y?OY_^L$`*#A"!"@X4G__^O3___J
M7-,```C4``!P0"WI/,&?Y2C03>(-X*#A#P"\Z`\`KN@L49_E#P"\Z`!@E>4-
M0*#A)&"-Y0\`KNBPP-SA%`&?Y;#`SN&]_?_K#`&?Y;O]_^L(`9_EN?W_ZP0!
MG^6W_?_K``&?Y;7]_^O\`)_EL_W_Z_@`G^6Q_?_K]`"?Y:_]_^OP`)_EK?W_
MZ^P`G^6K_?_KZ`"?Y:G]_^OD`)_EI_W_Z^``G^6E_?_KW`"?Y87]_^L`$%#B
MO`"?%1G__QO,`)_E@/W_ZP`04.+$`)\5%/__&\``G^5[_?_K`!!0X@L```J(
M`)_E#O__ZW@`G^6H$)_E"___ZR0@G>4`,)7E`P!2X1$``!HHT(WB<$"]Z![_
M+^&(`)_E:_W_ZP`04.("```*3`"?Y?[^_^ON___J$0"$XFP0G^4*(*#CA/G_
MZP``4./H__\:&Q"$XO3__^I/^?_K?-,```"V`0`0U```'-0``"34```PU```
M.-0``$C4``!4U```U-,``&#4``!LU```>-0``(C4``"4U```H-0``+34``#(
MU```U-0```35``#DU```^-0``!!`+>G@^/_K#/G_ZP``4.,``)`5$$"]Z![_
M+^$00"WI`$!0XA\```H`,-3E``!3XQP```KX^/_K`0!`X@`@A.`"`%3A],"?
M)0P``"KLP)_E``#4YP`PG.4`$-/E`0!0X0,```H=``#J`##2Y0``4^$:```:
M`2!"X@(`5.'Y__\Z!`!2X1H``!H``)SE`"#2Y0`PT.4#`%+A`@``"E#Y_^L`
M,*#A!P``Z@(`H.,*^?_K`#!0X@,```J$$)_E`B"@X]OX_^L`,*#A`P"@X1!`
MO>@>_R_A`##2Y0$`4^'G__\*`2!"X@(`5.'Y__\Z!`!2X>3__PH``)SE`2!"
MX@(`5.$#```J`!#2Y0`PT.4#`%'A^/__"@(@9.`",(+B`0I3XP`PH(/G__^*
M!!"@X0$@@N(0`)_E>?C_ZP@PG^7A___J7-,```C5```DM@$`<$`MZ0!0H.&P
M___K`##0Y0``4^,`0*`!"0``"F@@G^4`0*#A`""2Y0$`@.(`(-+E`@!3X0!`
MH`$!,-#D``!3X_K__QKI_/_K``!0XPD```H``%7C!P``"@`PU>4``%/C!```
M"@0`H.$@$)_EK/C_ZP``5.$!```*<$"]Z![_+^$%`*#A<$"]Z,;]_^I<TP``
M#-4``'!`+>D8T$WB%`"-Y1`0C>4,((WE%`"-XA`0C>(,((WB\?C_Z_P1G^7\
M`9_E`2"@X:P$`.L``*#C6/C_ZP!`T.4``%3C"P``&E'X_^O<(9_E``!0X_0/
M`N5P```*<_C_ZP0`H.'C^/_K``"0Y5KX_^N\^/_K`$#`Y0``H./=^/_K``"0
MY53X_^O@^/_K`"#0Y0`PH.$"((+C`"##Y0``H./4^/_K``"0Y4OX_^O7^/_K
M`##0Y0$P@^,`,,#E%$"=Y05`A.($`*#A=@4`ZP`@H.,`,*#CKP0`ZU0AG^54
M,9_E^P4`ZP``4.-)```:!`&@X:+X_^LT09_E`,"@X1``G>7PSP3E`#"0Y13@
MG>4`,(SE)#&?Y0$`7N,$,(SE'#&?Y0@PC.48,9_E##",Y00PH./L/P3E!P``
MV@P@H.$!,*#C`Q&0YP$P@^(#`%[A$!""Y00@@N+Y___*`^".XO0/%.4`4*#C
M#B"@X0PPH.'4$)_E`%"-Y0Y1C.?;]__K`%!0X@T```KT#Q3E1OC_Z[@`G^5J
M_/_K``!0XY!@G^41```*]`\4Y<?W_^L4^/_K!0"@X1C0C>)P0+WH'O\OX6PP
MG^5H8)_E]`\3Y=_W_^L`4*#A]`\4Y3/X_^ML`)_E5_S_ZP``4./M__\:Z`\6
MY0``4.,!```*7/__Z^C__^I,`)_E3OS_ZP``4./H#P;EX___"O?__^HX`)_E
M.!"?Y4[X_^L!`*#CA?C_ZV2;``!XG```&-8!````@/___\]!%-4``&37```8
MU0``Z,P``$C4``!4U```X-4```RV`0#P3RWI["&?Y0':3>(`,)+E'-!-X@$J
MC>(`<*#A%#""Y=0!G^4!@*#A+?S_Z\RAG^4`8*#A`$":Y0<`H.$$$*#A^_?_
MZP!04.(-```*!Q"@X:P!G^6Y_?_KF!&?Y0$ZC>(4()/E`#"1Y0<`H.$#`%+A
M7P``&AS0C>(!VHWB\$^]Z![_+^$'`*#AU/?_ZQR0FN4`,*#A"1"@X0@`H.$(
M,(WE!/C_ZP"P4.((,)WE0```"AB`C>(!,(/B2*&?Y0PPC>4$@$CB`##;Y0``
M4^,*L*`!``!6XP0```H&`*#A"Q"@X3SX_^L``%#C+```"@L`H.&Z]__K`#"+
MX`$04^4`(-3E`@!1X08``!H!4$/E`B!3Y0`0U.4!`$#B`@!1X0$P0^+X__\*
M##"=Y=P0G^4``(/@`0!0X<3__\H+(*#AS!"?Y00PH.$(`*#A`'"-Y2KX_^L`
M`*#C$/C_ZP``D.6']__KW??_ZP@0H.$`(*#A`P"@X[[W_^L``%#C!P``&@;X
M_^L``)#E???_Z]/W_^L0,)#E#SH#X@()4^,)```*``"@XPD0H.'#]__K``!0
MXP"PH.'#__\:!Q"@X40`G^5?_?_KI/__Z@@`H.$!$*#C;O?_ZP``4./P__\:
M"!"@X2``G^56_?_K"`"@X>[W_^L`<*#AF/__ZJSW_^L`M@$`5-0``%S3``!X
MU```"-4``/\/```(U```\$\MZ8'<3>*,T$WB?!F?Y6)OC>)X>9_E!E"@X0`@
MD>784$7B`DF-XL!@1N)$,(?B5,"'X@6`H.&$(83E`*"@X0\`D^@/`(;H#P"\
MZ`\`J.@#`)SH"#"@X6*/C>)LP(?BL(!(X@,`@^@'`)SH!P"(Z"`)G^65^__K
M`$!0X@(```H`,-3E``!3X^D``!I'_O_K`$!0XNL```H`@-3E``!8XPH```II
M]__K!#"@X5\0H.,`()#EB("@X;@@DN$(`!+C`!##!0&`\^4``%CC]___&L0X
MG^6!O(WBB+"+X@,`F^<`,-#E``!3XP0``!JZ``#J!`"UY0`PT.4``%/CM@``
M"G+[_^L`@%#B^/__"JO\_^L``%#C]?__"@@`H.&<]__K`(!0XO'__PH(`*#A
M)O?_ZP!@H.$$`*#A(_?_ZP!@AN`!:X;B!&"&X@8`H.%.]__K`%"@X08`H.%+
M]__K`'"7Y3C(G^4`8*#A"""@X3`8G^4',*#A`,"-Y01`C>69]__K!@"@X0<=
MH..O]O_K`0!PXW````J(0(WB0$!$X@,`H.,&$*#A!""@X6'W_^L!`'#CRP$`
M"A`PE.4/.@/B`0E3XW(``!H8@)3EV_;_ZP``6.%N```:$#"4Y8,[H.&C.Z#A
M!PU3XVD``!JX!Y_E-_O_ZP``4..F```*`$":Y63W_^L`$*#A!`"@X??^_^L`
M0%#BGP``"@0`H.'K]O_K`P!0XP"`H.$9``#:!`!`X@``A.!T%Y_E8O?_ZP``
M4.,3```:!`!8XP0```H(@(3@!2!8Y0`PU^4#`%+A#```&@2`FN4``%CC"0``
M"@@`H.'6]O_K`P!0XP4``)H$`$#B``"(X"@7G^5.]__K``!0XP````H$@*#A
M%/O_ZP`04.(<4(WE!```&@@`H.'6]O_K`"!0XB0@C>5Z```:]!:?Y?0&G^69
M_/_K#O?_Z^R&G^4``(WEZ!:?Y04`H.$&(*#A!S"@X02`C>4`0*#C/O?_ZPP`
M`.HY]__K`#"0Y1$`4^,-```:__;_ZP%`A.(``(WEL!:?Y04`H.$&(*#A!S"@
MX1`!C>DP]__K!0"@X0<=H.-&]O_K`0!PX^W__PH&`*#AA/;_ZP40H.%,!I_E
M=_S_ZP4`H.'L_/_K%0``ZA_W_^L`P)#E$0!<XXK__PI8-I_E`"":Y0``D^50
M%I_E!C"@X0#`C>6X]O_K`,"@XQS`C>4'``#J,#:?Y306G^4``)/E`"":Y08P
MH.&O]O_K`!"@XQP0C>78E9_E`HF-XH0AF.4`,)GE'`"=Y0,`4N%O`0`:8]^-
MX@+9C>+P3[WH'O\OX?`UG^6!O(WBB+"+X@-0F^<`@-7E``!8XP0``!I*___J
M!%"VY0`PU>4``%/C!P``"@4`H.'J^__K``!0X_?__PH%`*#AV_;_ZP``4./S
M__\*`("@X3S__^JS_/_K!`"@X=3V_^L<`(WEV?__ZH@UG^6!G(WBB)")X@,`
MF><`,-#E``!3XPD```J9^O_K``!0XP(```K']O_K``!0XP<``!H$`+CE`##0
MY0``4^/U__\:2$6?Y0[__^H`0)KE7?__Z@!`H.'\_O_J8C^-XJ0P0^(@,(WE
M$2#@XP`PX.,"0*#C`$"-Y6[V_^LD`)WE(!"=Y08@H.,B]O_K@8R-X@`UG^6(
M@(CB`S#8YP``4^,#```:()"=Y0$PV>5#`%/C!@$`"@!`H.,`,*#C)`"=Y0`@
MH.,`0(WE6O;_Z\@TG^4"N8WBY#"+Y2(S@^(B-X/B(CN#XH@P@^+H,(OEK#2?
MY0*9C>+L,(OEI#2?Y>20B>+P,(OEG#2?Y1S`B>+T,(OE0$&+Y?A`B^7\0(OE
M*,"-Y8&\C>('H*#A!8"@X20`G>4@$)WE`BF@X_;U_^L`4%#B/0``V@+IC>+X
M()[E`DF-XH4Q@N`#`%+A`AF-@OP@D84.`*"1_""0E4`!E.4!((*"I2Z"X```
M4./X,(3E_""$Y2!PG043```*0'!@XBC`G>4'`%7A!7"@L0=PH*$``(S@(!"=
MY0<@H.'[]?_K`NF-XD`QGN4#,(?@0`!3XT`QCN79__\:(!"=Y0D`H.$%4&?@
M!W"!X+GV_^L_`%7C#P``V@!`H.,$$(?@0""@XPL`H.'I]?_K0$"$X@D`H.&O
M]O_K!3!DX#\`4^/U___*0%!%XB4SH.$!((/B`G.'X`-31>`%(*#A!Q"@X2@`
MG>7:]?_K`BF-XD!1@N6[___J)`"=Y>?U_^L".8WB^$"3Y0A0H.&D(:#A/R`"
MXH&,C>(!,(+BB("(X@(@B.`"N8WB?Q#@XS@`4^/\@)OE"G"@X8@00N5M``#*
M'`")X@,`@.`X(&/B`!"@XX?U_^LH[*#A*,B@X2@4H.$D+*#A)#2@X0D`H.$D
MJ*#A@9R-X@*YC>(XX,GE.<#)Y3H0R>4[@,GE/"#)Y3V@R>4^,,GE/T#)Y7?V
M_^OHP)OE[`";Y>3@F^7P$)OE]#";Y2RTH.$@L(WE(+B@X2BPC>4AO*#A,+"-
MY2&TH.$LF*#A.+"-Y2.XH.$4D(WE0+"-Y2"<H.&!O(WB+HB@X2Y$H.$DD(WE
M+BR@X2"4H.%SX,OE%."=Y2R0C>4AF*#A+*R@X320C>5Q@,OE(YR@X22`G>5R
M0,OE=>#+Y2!`G>4LX)WE=\#+Y7L`R^4HP)WE,`"=Y3R0C>4CE*#A1)"-Y72@
MR^5V0,OE>(#+Y7G`R^5ZX,OE@9R-XGP`R^4T0(WB$%&4Z$0`G>5$D(GB@:R-
MXGU`R^5^@,OE?Q#+Y8#`R^6!X,OE@@#+Y8,PR^5P(,OE"8"@X0!`H.-PH(KB
M````Z@0@VN<(`*#A`4"$XJ@1G^7F]?_K%`!4XP*`B.+W__\:`,"@XX%,C>)L
MP,3E4,&?Y0<PH.$%`*#A@!&?Y08@H.$`$HWHV?7_ZZS^_^H<`(GB0"!CX@,`
M@.``$*#C&?7_ZPD`H.$9]O_K`#"@XP+)C>(T,8SE`#&,Y00QC.4(,8SE##&,
MY1`QC.44,8SE&#&,Y1PQC.4@,8SE)#&,Y2@QC.4L,8SE,#&,Y7[__^J\]?_K
MV#"?Y0#`D.4`,)/E`"":Y0,`H.'X$)_E!C"@X0#`C>56]?_K``"@XQP`C>6E
M_O_J`C#9Y4$`4^/U_O\:`S#9Y4,`4^/R_O\:!##9Y4@`4^/O_O\:!3#9Y44`
M4^/L_O\:`##@XSD@X.,D`)WE`$"-Y4CU_^L@$)WE)`"=Y2D@H./\]/_K2,"?
MY0<PH.$%`*#A>!"?Y08@H.$`$HWHE_7_ZVK^_^I!]?_K`+8!`%S3``!4U```
M*'___PS5```<U0``2-<``,35``#,U0``!-4``-33```0U0``[-4``/S5```(
MM@$`*-4``)S5``!`?___4'___Q#6``!<?___`2-%9_[<NIAV5#(0\.'2P^35
M``#4U0``9-4``/!'+>D``*#C7O7_ZP``D.75]/_KVO3_ZP$PH.,`,,#EC`.?
MY2GY_^L``%#C`@``"@`PT.4Q`%/CB0``"G/[_^L``*#C3_7_ZP``D.7&]/_K
M8!.?Y0$@H.,+,*#CI/3_ZP``4.-08Y\%-```"DACG^4,()#E[#\6Y1B`DN4!
M`%/C`%"@TRH``-H`4*#C`4"@XP@``.H'`*#A2?7_ZP``4.,B```:[#\6Y0%`
MA.($`%/A`5"%XAX``-H``*#C,?7_ZP``D.6H]/_K"!"@X04@H.$`,*#CSO3_
MZP"04.(3```*`#"9Y?`O%N4(H)/E!'&2YP&K&N(,$),5Y?__&@H`H.$@]?_K
M``"0Y9?T_^L`$)GE"B"@X0(PH.,X]?_K`!"@X0<`H.$F]?_K``!0X]S__PKL
M/Q;E`2!#X@4`4N%,```*``"@XP_U_^L``)#EAO3_ZV@2G^4!(*#C!3"@XV3T
M_^L`0%#B#```"@``H.,%]?_K``"0Y7ST_^L,,)3E0"*?Y0`0D^5@]/_K##"4
MY0`PD^4(,)/E`043XT,``!H``*#C^/3_ZP``D.5O]/_K%!*?Y0$@H.,%,*#C
M3?3_ZP!`4.(+```*``*?Y<#X_^L`4%#B/0``"@``H./J]/_K``"0Y6'T_^L,
M,)3E!2"@X0`0D^5%]/_K``"@X^+T_^L``)#E6?3_ZU[T_^L`4*#C`%#`Y04`
MH.';]/_K``"0Y5+T_^OD]/_K`%"`Y:`!G^6G^/_K!0!0X>@/!N5\49_E*P``
M"HP1G^4`]/_K$0!0XP``4!,!```*`0!PXT\``!KP1[WH'O\OX0$PT.4``%/C
M<___"G'__^H!`%/CL/__V@%`H.,``*#CO_3_ZP``D.4V]/_K"!"@X1/T_^OL
M/Q;E`4"$X@0`4^'U___*I/__Z@``H..T]/_K``"0Y2OT_^L,,)3E`!"3Y6KT
M_^NS___JK?3_ZP``D.4D]/_K#""4Y?`_%N4`$)+E`""3Y:SX_^O`___J\`\5
MY<'\_^OH#P7E##"4Y0`PD^4(4)/E`5L5X@P`DQ4(```:!0"@X9KT_^L``)#E
M$?3_ZPPPE.4%(*#A`!"3Y0(PH..Q]/_K\!\6Y?7S_^L,,)3E\"\6Y0`PD^4`
M8)+E"'"3Y0!0H.$!>Q?B#""3%0D``!H'`*#AAO3_ZP``D.7]\__K##"4Y0<@
MH.$`$)/E`C"@XYWT_^L`(*#A!A"@X04PH.$\`)_E4_3_Z_`_%>7H+Q7E`!"3
MY0`PH.$H`)_E3?3_ZSC4```8U@``&-8!`"#6```DU@``+-8``'C4``!4U```
M[0$``##6``!@U@``$$`MZ0``H.-F]/_K``"0Y=WS_^L0$)_E$""?Y1`PG^57
M]/_K$$"]Z![_+^&PU@``;)P``,S6```$X"WE``"@XPS03>)7]/_K``"0Y<[S
M_^OJ___K``"@XU+T_^L``)#ER?/_ZR#`G^4`X*#C##"@X1@0G^48()_E`%"-
MZ-3S_^L,T(WB!."=Y![_+^$0U0``V-8``-#(```@,)_E(,"?Y0,PC^`00"WI
M#."3X`XPH`$,,),7$?3_ZQ!`O>@>_R_A..<``%@!```>_R_A\$<MZ5B@G^58
M4)_E`&"@X0%PH.$"@*#A5//_ZT@PG^4%4&K@`S"/X$51L.$*H(/@"0``"@!`
MH.,&`*#A!Q"@X0@@H.$$P9KG#^"@X1S_+^$!0(3B!0!4X?;__SKP1[WH'O\O
MX=3^___8_O__Z.8```(1(>(```#J`C$CXC!`+>F!0*#A@U"@X04`-.$"`#`!
M`,"4$0+`E1'$RO`1Q<KP$8P```JD2J#AI5ITX`!09;(&``#:!4"$X`(@(.`#
M,"'@```BX`$0(^`"("#@`S`AX#8`5>,P0+V('O\O@0(!$>,!%J#A`<:@XR$6
MC.$!```*``!PX@`0X>("`1/C`S:@X2,VC.$!```*`"!RX@`PX^(%`#3A:0``
M"@%`1.(@X'7B!0``NA+.H.$R!9#@`!"AXA,.D.!3%;'@!@``ZB!01>(@X([B
M`0!2XQ/.H.$"P(PC4P60X,,?L>`"40'B`@``6@#`?.(``/#B`!#AX@$&4>,/
M```Z`@91XP8``#JA$+#A8`"PX6S`H.$!0(3BA"J@X0$%<N-K```J`@%<XZ#`
ML`$``+#B!!JAX`40@>$P0+WH'O\OX8S`L.$``+#@`1"AX`$&$>,!0$3B\O__
M&@``,>,4,*`3-#"@`P`0H`$``*`#`2"@X0$(4N,B**`A$#!#(@$,4N,B)*`A
M"#!#(A``4N,B(J`A!#!#(@0`4N,",$,BHC!#,*(Q0^`@(%/B!P``J@P@DN($
M``#:%,""X@P@8N(1#*#A,1*@X00``.H4((+B(,!BTA$2H.$P'('1$`*@T0-`
M5.`$&H&@!1"!H3!`O:@>_R^A!$#@X1]`5.(/``"J#$"4X@8``,H40(3B("!D
MXC`$H.$1`H#A,12%X3!`O>@>_R_A#$!DXB`@9.(P`J#A$02`X040H.$P0+WH
M'O\OX3$$H.$%$*#A,$"]Z![_+^$``#3C`38CX@$6(0(!0(0"`5!%$H___^K$
MRO#AQ<KP$1T```H%`#3A`@`P`00```H`P)3A`Q"@`0(`H`$P0+WH'O\OX0,`
M,>$`$*`3``"@$S!`O1@>_R\1I,JPX00``!J``+#A`1"QX`(1@2,P0+WH'O\O
MX0%%E.(!%H$R,$"].![_+S$"40'B?Q2%XP\6@>,``*#C,$"]Z![_+^'$RO#A
M`Q"@$0(`H!'%RO`!`3"@$0`@H!$!1I#A`U:2`0,`,0$"%X$3,$"]Z![_+^$`
M`##C`!"@`Q[_+P$P0"WI`4N@XS)`A.(`4*#C`!"@XX;__^H``##C`!"@`Q[_
M+P$P0"WI`4N@XS)`A.("41#B``!@0@`0H.-\___J@""PX<(1H.%A$*#A`@Z@
MX?\T$A+_!#,3#A,A$A[_+Q$``#+C_P0S$Q[_+P$P0"WI#DV@XP)1`>("$<'C
M;/__Z@$@D.$>_R\!,$`MZ0!0H.,&``#J`2"0X1[_+P$P0"WI`E$1X@$``%H`
M`'#B`!#AX@%+H.,R0(3B(<NPX43__PH#(*#CK,&PX0,@@A*LP;#A`R""$JPA
M@N`@,&+B$,.@X3`"H.$1`X#A,1*@X0)`A.`W___J`,#@XP(``.H!P*#C````
MZ@'`H.,$P"WE@<"@X<S*\.&#P*#AS,KP$0X```H$T(WB@<"0X8/`D@$#`#$1
M`@`P`0``H`,>_R\!``!PXP,`,>$#`%%1`@!0`<,/H"'##^`Q`0"`XQ[_+^&!
MP*#AS,KPX0$``!H!QI#A!```&H/`H.',RO#AZ/__&@/&DN'F__\*!`"=Y![_
M+^$`P*#A`@"@X0P@H.$!P*#A`Q"@X0PPH.'____J`4`MZ=3__^L``%#C``!P
M0P%`O>@>_R_A".`MY??__^L!`*`#``"@$PC@G>0>_R_A".`MY?'__^L!`*`S
M``"@(PC@G>0>_R_A".`MY>O__^L!`*"3``"@@PC@G>0>_R_A".`MY=[__^L!
M`*"3``"@@PC@G>0>_R_A".`MY=C__^L!`*`S``"@(PC@G>0>_R_A$$`MZ1!`
MO>@>_R_A`0`"`/#6```HUP``.-<``$#7``!(UP``4-<``!#5```DUP``7U]%
M3E9?4$%27T-,14%.7U\@("`@("`@("`@("`@("``````%-<``!S7```(U0``
M$-4``,C4``#,U```"-<``%C4```0UP``$-4``/36``#\U@``$-4``%!!4E]#
M3$5!3@```"]P<F]C+W-E;&8O97AE```E<R\E<P```"]P<F]C+R5I+R5S`&5X
M90`E<R5S)7,``%!%4DPU3$E"`````%!%4DQ,24(`4$523#5/4%0`````4$52
M3$E/``!005)?24Y)5$E!3$E:140`4$%27U-005=.140`4$%27U1%35``````
M4$%27T1%0E5'````4$%27T-!0TA%````4$%27U!23T=.04U%`````%!!4E]!
M4D=#`````%!!4E]!4D=67S```%!!4E]'3$]"04Q?1$5"54<`````4$%27T=,
M3T)!3%]435!$25(```!005)?5$U01$E2``!005)?1TQ/0D%,7U1%35``4$%2
M7T=,3T)!3%]#3$5!3@````!005)?0TQ%04X]```Q````+@```'!A<BT`````
M+64``"TM```E<R5S)7,E<P`````E<SH@8W)E871I;VX@;V8@<')I=F%T92!S
M=6)D:7)E8W1O<GD@)7,@9F%I;&5D("AE<G)N;STE:2D*```E<SH@<W1A="!O
M9B!P<FEV871E('-U8F1I<F5C=&]R>2`E<R!F86EL960@*&5R<FYO/25I*0H`
M`"5S.B!P<FEV871E('-U8F1I<F5C=&]R>2`E<R!I<R!U;G-A9F4*``!P87)L
M`````"YP87(`````)7,E<V-A8VAE+25S)7,``"4P,G@`````)7,E<W1E;7`M
M)74E<P```"5S)7-T96UP+25U+25U)7,`````4UE35$5-``!!4D=6`````!@`
M``!P97)L`````#`````E<SH@97AE8W5T:6]N(&]F("5S(&9A:6QE9"`M(&%B
M;W)T:6YG('=I=&@@)6DN"@`E<SH@8W)E871I;VX@;V8@<')I=F%T92!T96UP
M;W)A<GD@<W5B9&ER96-T;W)Y("5S(&9A:6QE9"`M(&%B;W)T:6YG('=I=&@@
M)6DN"@```$1Y;F%,;V%D97(Z.F)O;W1?1'EN84QO861E<@!P97)L>'-I+F,`
M``!);G1E<FYA;',Z.E!!4CHZ0D]/5``````O````55-%4@````!54T523D%-
M10````!414U01$E2`%1-4`!#.EQ414U0`"]T;7``````.@```$Q$7TQ)0E)!
M4EE?4$%42`!,24)0051(`$Q)0E)!4EE?4$%42`````!$64Q$7TQ)0E)!4EE?
M4$%42````",A+W5S<B]B:6XO<&5R;`IE=F%L("=E>&5C("]U<W(O8FEN+W!E
M<FP@("U3("0P("1[,2LB)$`B?2<*("`@(&EF(#`[(",@;F]T(')U;FYI;F<@
M=6YD97(@<V]M92!S:&5L;`H*<&%C:V%G92!?7W!A<E]P;#L*"B,@+2TM(%1H
M:7,@<V-R:7!T(&UU<W0@;F]T('5S92!A;GD@;6]D=6QE<R!A="!C;VUP:6QE
M('1I;64@+2TM"B,@=7-E('-T<FEC=#L*"B-L:6YE(#$U.`H*;7D@*"1P87)?
M=&5M<"P@)'!R;V=N86UE+"!`=&UP9FEL92D["D5.1"![(&EF("@D14Y6>U!!
M4E]#3$5!3GTI('L*("`@(')E<75I<F4@1FEL93HZ5&5M<#L*("`@(')E<75I
M<F4@1FEL93HZ0F%S96YA;64["B`@("!R97%U:7)E($9I;&4Z.E-P96,["B`@
M("!M>2`D=&]P9&ER(#T@1FEL93HZ0F%S96YA;64Z.F1I<FYA;64H)'!A<E]T
M96UP*3L*("`@(&]U=',H<7%[4F5M;W9I;F<@9FEL97,@:6X@(B1P87)?=&5M
M<")]*3L*("`@($9I;&4Z.D9I;F0Z.F9I;F1D97!T:"AS=6(@>R`H("UD("D@
M/R!R;61I<B`Z('5N;&EN:R!]+"`D<&%R7W1E;7`I.PH@("`@<FUD:7(@)'!A
M<E]T96UP.PH@("`@(R!$;VXG="!R96UO=F4@=&]P9&ER(&)E8V%U<V4@=&AI
M<R!C875S97,@82!R86-E('=I=&@@;W1H97(@87!P<PH@("`@(R!T:&%T(&%R
M92!T<GEI;F<@=&\@<W1A<G0N"@H@("`@:68@*"UD("1P87)?=&5M<"`F)B`D
M7D\@;F4@)TU35VEN,S(G*2!["B`@("`@("`@(R!3;VUE=&AI;F<@=V5N="!W
M<F]N9R!U;FQI;FMI;F<@=&AE('1E;7!O<F%R>2!D:7)E8W1O<GDN("!4:&ES
M"B`@("`@("`@(R!T>7!I8V%L;'D@:&%P<&5N<R!O;B!P;&%T9F]R;7,@=&AA
M="!D:7-A;&QO=R!U;FQI;FMI;F<@<VAA<F5D"B`@("`@("`@(R!L:6)R87)I
M97,@86YD(&5X96-U=&%B;&5S('1H870@87)E(&EN('5S92X@56YL:6YK('=I
M=&@@82!B86-K9W)O=6YD"B`@("`@("`@(R!S:&5L;"!C;VUM86YD('-O('1H
M92!F:6QE<R!A<F4@;F\@;&]N9V5R(&EN('5S92!B>2!T:&ES('!R;V-E<W,N
M"B`@("`@("`@(R!$;VXG="!D;R!A;GET:&EN9R!O;B!7:6YD;W=S(&)E8V%U
M<V4@;W5R('!A<F5N="!P<F]C97-S('=I;&P*("`@("`@("`C('1A:V4@8V%R
M92!O9B!C;&5A;FEN9R!T:&EN9W,@=7`N"@H@("`@("`@(&UY("1T;7`@/2!N
M97<@1FEL93HZ5&5M<"@*("`@("`@("`@("`@5$5-4$Q!5$4@/3X@)W1M<%A8
M6%A8)RP*("`@("`@("`@("`@1$E2(#T^($9I;&4Z.D)A<V5N86UE.CID:7)N
M86UE*"1T;W!D:7(I+`H@("`@("`@("`@("!3549&25@@/3X@)RYC;60G+`H@
M("`@("`@("`@("!53DQ)3DL@/3X@,"P*("`@("`@("`I.PH*("`@("`@("!P
M<FEN="`D=&UP("(C(2]B:6XO<V@*>#TQ.R!W:&EL92!;(%PD>"`M;'0@,3`@
M73L@9&\*("`@<FT@+7)F("<D<&%R7W1E;7`G"B`@(&EF(%L@7"$@+60@)R1P
M87)?=&5M<"<@73L@=&AE;@H@("`@("`@8G)E86L*("`@9FD*("`@<VQE97`@
M,0H@("!X/6!E>'!R(%PD>"`K(#%@"F1O;F4*<FT@)R(@+B`D=&UP+3YF:6QE
M;F%M92`N("(G"B(["B`@("`@("`@("`@(&-H;6]D(#`W,#`L)'1M<"T^9FEL
M96YA;64["B`@("`@("`@;7D@)&-M9"`]("1T;7`M/F9I;&5N86UE("X@)R`^
M+V1E=B]N=6QL(#(^)C$@)B<["B`@("`@("`@8VQO<V4@)'1M<#L*("`@("`@
M("!S>7-T96TH)&-M9"D["B`@("`@("`@;W5T<RAQ<2A3<&%W;F5D(&)A8VMG
M<F]U;F0@<')O8V5S<R!T;R!P97)F;W)M(&-L96%N=7`Z("D*("`@("`@("`@
M("`@("X@)'1M<"T^9FEL96YA;64I.PH@("`@?0I]('T*"D)%1TE.('L*("`@
M($EN=&5R;F%L<SHZ4$%2.CI"3T]4*"D@:68@9&5F:6YE9"`F26YT97)N86QS
M.CI005(Z.D)/3U0["@H@("`@979A;"!["@I?<&%R7VEN:71?96YV*"D["@II
M9B`H97AI<W1S("1%3E9[4$%27T%21U9?,'T@86YD("1%3E9[4$%27T%21U9?
M,'T@*2!["B`@("!`05)'5B`](&UA<"`D14Y6>R)005)?05)'5E\D7R)]+"`H
M,2`N+B`D14Y6>U!!4E]!4D=#?2`M(#$I.PH@("`@)#`@/2`D14Y6>U!!4E]!
M4D=67S!].PI]"F5L<V4@>PH@("`@9F]R("AK97ES("5%3E8I('L*("`@("`@
M("!D96QE=&4@)$5.5GLD7WT@:68@+UY005)?05)'5E\O.PH@("`@?0I]"@IM
M>2`D<75I970@/2`A)$5.5GM005)?1$5"54=].PH*(R!F:7@@)'!R;V=N86UE
M(&EF(&EN=F]K960@9G)O;2!0051("FUY("5#;VYF:6<@/2`H"B`@("!P871H
M7W-E<"`@("`]/B`H)%Y/(#U^("]>35-7:6XO(#\@)SLG(#H@)SHG*2P*("`@
M(%]E>&4@("`@("`@(#T^("@D7D\@/7X@+UXH/SI-4U=I;GQ/4S)\8WEG=VEN
M*2\@/R`G+F5X92<@.B`G)RDL"B`@("!?9&5L:6T@("`@("`]/B`H)%Y/(#U^
M("]>35-7:6Y\3U,R+R`_("=<7"<@.B`G+R<I+`HI.PH*7W-E=%]P<F]G;F%M
M92@I.PI?<V5T7W!A<E]T96UP*"D["@HC($UA9VEC('-T<FEN9R!C:&5C:VEN
M9R!A;F0@97AT<F%C=&EN9R!B=6YD;&5D(&UO9'5L97,@>WM["FUY("@D<W1A
M<G1?<&]S+"`D9&%T85]P;W,I.PI["B`@("!L;V-A;"`D4TE'>U]?5T%23E]?
M?2`]('-U8B![?3L*"B`@("`C($-H96-K(&9I;&4@='EP92P@9V5T('-T87)T
M(&]F(&1A=&$@<V5C=&EO;B![>WL*("`@(&]P96X@7T9(+"`G/"<L("1P<F]G
M;F%M92!O<B!L87-T.PH@("`@8FEN;6]D92A?1D@I.PH*("`@(&UY("1B=68[
M"B`@("!S965K(%]&2"P@+3@L(#(["B`@("!R96%D(%]&2"P@)&)U9BP@.#L*
M("`@(&QA<W0@=6YL97-S("1B=68@97$@(EQN4$%2+G!M7&XB.PH*("`@('-E
M96L@7T9(+"`M,3(L(#(["B`@("!R96%D(%]&2"P@)&)U9BP@-#L*("`@('-E
M96L@7T9(+"`M,3(@+2!U;G!A8VLH(DXB+"`D8G5F*2P@,CL*("`@(')E860@
M7T9(+"`D8G5F+"`T.PH*("`@("1D871A7W!O<R`]("AT96QL(%]&2"D@+2`T
M.PH@("`@(R!]?7T*"B`@("`C($5X=')A8W1I;F<@96%C:"!F:6QE(&EN=&\@
M;65M;W)Y('M[>PH@("`@;7D@)7)E<75I<F5?;&ES=#L*("`@('=H:6QE("@D
M8G5F(&5Q(")&24Q%(BD@>PH@("`@("`@(')E860@7T9(+"`D8G5F+"`T.PH@
M("`@("`@(')E860@7T9(+"`D8G5F+"!U;G!A8VLH(DXB+"`D8G5F*3L*"B`@
M("`@("`@;7D@)&9U;&QN86UE(#T@)&)U9CL*("`@("`@("!O=71S*'%Q*%5N
M<&%C:VEN9R!F:6QE("(D9G5L;&YA;64B+BXN*2D["B`@("`@("`@;7D@)&-R
M8R`]("@@)&9U;&QN86UE(#U^('-\7BA;82UF7&1=>SA]*2]\?"`I(#\@)#$@
M.B!U;F1E9CL*("`@("`@("!M>2`H)&)A<V5N86UE+"`D97AT*2`]("@D8G5F
M(#U^(&U\*#\Z+BHO*3\H+BHI*%PN+BHI?"D["@H@("`@("`@(')E860@7T9(
M+"`D8G5F+"`T.PH@("`@("`@(')E860@7T9(+"`D8G5F+"!U;G!A8VLH(DXB
M+"`D8G5F*3L*"B`@("`@("`@:68@*&1E9FEN960H)&5X="D@86YD("1E>'0@
M(7X@+UPN*#\Z<&U\<&Q\:7A\86PI)"]I*2!["B`@("`@("`@("`@(&UY("@D
M;W5T+"`D9FEL96YA;64I(#T@7W1E;7!F:6QE*"1E>'0L("1C<F,I.PH@("`@
M("`@("`@("!I9B`H)&]U="D@>PH@("`@("`@("`@("`@("`@8FEN;6]D92@D
M;W5T*3L*("`@("`@("`@("`@("`@('!R:6YT("1O=70@)&)U9CL*("`@("`@
M("`@("`@("`@(&-L;W-E("1O=70["B`@("`@("`@("`@("`@("!C:&UO9"`P
M-S4U+"`D9FEL96YA;64["B`@("`@("`@("`@('T*("`@("`@("`@("`@)%!!
M4CHZ2&5A=GDZ.D9U;&Q#86-H97LD9G5L;&YA;65](#T@)&9I;&5N86UE.PH@
M("`@("`@("`@("`D4$%2.CI(96%V>3HZ1G5L;$-A8VAE>R1F:6QE;F%M97T@
M/2`D9G5L;&YA;64["B`@("`@("`@?0H@("`@("`@(&5L<VEF("@@)&9U;&QN
M86UE(#U^(&U\7B\_<VAL:6(O?"!A;F0@9&5F:6YE9"`D14Y6>U!!4E]414U0
M?2`I('L*("`@("`@("`@("`@(R!S:&]U;&0@8F4@;6]V960@=&\@7W1E;7!F
M:6QE*"D*("`@("`@("`@("`@;7D@)&9I;&5N86UE(#T@(B1%3E9[4$%27U1%
M35!]+R1B87-E;F%M921E>'0B.PH@("`@("`@("`@("!O=71S*")32$Q)0CH@
M)&9I;&5N86UE7&XB*3L*("`@("`@("`@("`@;W!E;B!M>2`D;W5T+"`G/B<L
M("1F:6QE;F%M92!O<B!D:64@)"$["B`@("`@("`@("`@(&)I;FUO9&4H)&]U
M="D["B`@("`@("`@("`@('!R:6YT("1O=70@)&)U9CL*("`@("`@("`@("`@
M8VQO<V4@)&]U=#L*("`@("`@("!]"B`@("`@("`@96QS92!["B`@("`@("`@
M("`@("1R97%U:7)E7VQI<W1[)&9U;&QN86UE?2`]"B`@("`@("`@("`@("10
M05(Z.DAE879Y.CI-;V1U;&5#86-H97LD9G5L;&YA;65](#T@>PH@("`@("`@
M("`@("`@("`@8G5F(#T^("1B=68L"B`@("`@("`@("`@("`@("!C<F,@/3X@
M)&-R8RP*("`@("`@("`@("`@("`@(&YA;64@/3X@)&9U;&QN86UE+`H@("`@
M("`@("`@("!].PH@("`@("`@('T*("`@("`@("!R96%D(%]&2"P@)&)U9BP@
M-#L*("`@('T*("`@(",@?7U]"@H@("`@;&]C86P@0$E.0R`]("AS=6(@>PH@
M("`@("`@(&UY("@D<V5L9BP@)&UO9'5L92D@/2!`7SL*"B`@("`@("`@<F5T
M=7)N(&EF(')E9B`D;6]D=6QE(&]R("$D;6]D=6QE.PH*("`@("`@("!M>2`D
M9FEL96YA;64@/2!D96QE=&4@)')E<75I<F5?;&ES='LD;6]D=6QE?2!\?"!D
M;R!["B`@("`@("`@("`@(&UY("1K97D["B`@("`@("`@("`@(&9O<F5A8V@@
M*&ME>7,@)7)E<75I<F5?;&ES="D@>PH@("`@("`@("`@("`@("`@;F5X="!U
M;FQE<W,@+UQ1)&UO9'5L95Q%)"\["B`@("`@("`@("`@("`@("`D:V5Y(#T@
M)%\[(&QA<W0["B`@("`@("`@("`@('T*("`@("`@("`@("`@9&5L971E("1R
M97%U:7)E7VQI<W1[)&ME>7T@:68@9&5F:6YE9"@D:V5Y*3L*("`@("`@("!]
M(&]R(')E='5R;CL*"B`@("`@("`@)$E.0WLD;6]D=6QE?2`]("(O;&]A9&5R
M+R1F:6QE;F%M92\D;6]D=6QE(CL*"B`@("`@("`@:68@*"1%3E9[4$%27T-,
M14%.?2!A;F0@9&5F:6YE9"@F24\Z.D9I;&4Z.FYE=RDI('L*("`@("`@("`@
M("`@;7D@)&9H(#T@24\Z.D9I;&4M/FYE=U]T;7!F:6QE(&]R(&1I92`D(3L*
M("`@("`@("`@("`@8FEN;6]D92@D9F@I.PH@("`@("`@("`@("!P<FEN="`D
M9F@@)&9I;&5N86UE+3Y[8G5F?3L*("`@("`@("`@("`@<V5E:R@D9F@L(#`L
M(#`I.PH@("`@("`@("`@("!R971U<FX@)&9H.PH@("`@("`@('T*("`@("`@
M("!E;'-E('L*("`@("`@("`@("`@;7D@*"1O=70L("1N86UE*2`](%]T96UP
M9FEL92@G+G!M)RP@)&9I;&5N86UE+3Y[8W)C?2D["B`@("`@("`@("`@(&EF
M("@D;W5T*2!["B`@("`@("`@("`@("`@("!B:6YM;V1E*"1O=70I.PH@("`@
M("`@("`@("`@("`@<')I;G0@)&]U="`D9FEL96YA;64M/GMB=69].PH@("`@
M("`@("`@("`@("`@8VQO<V4@)&]U=#L*("`@("`@("`@("`@?0H@("`@("`@
M("`@("!O<&5N(&UY("1F:"P@)SPG+"`D;F%M92!O<B!D:64@)"$["B`@("`@
M("`@("`@(&)I;FUO9&4H)&9H*3L*("`@("`@("`@("`@<F5T=7)N("1F:#L*
M("`@("`@("!]"@H@("`@("`@(&1I92`B0F]O='-T<F%P<&EN9R!F86EL960Z
M(&-A;FYO="!F:6YD("1M;V1U;&4A7&XB.PH@("`@?2P@0$E.0RD["@H@("`@
M(R!.;W<@;&]A9"!A;&P@8G5N9&QE9"!F:6QE<R![>WL*"B`@("`C(&EN:71I
M86QI>F4@<VAA<F5D(&]B:F5C="!P<F]C97-S:6YG"B`@("!R97%U:7)E(%A3
M3&]A9&5R.PH@("`@<F5Q=6ER92!005(Z.DAE879Y.PH@("`@<F5Q=6ER92!#
M87)P.CI(96%V>3L*("`@(')E<75I<F4@17AP;W)T97(Z.DAE879Y.PH@("`@
M4$%2.CI(96%V>3HZ7VEN:71?9'EN86QO861E<B@I.PH*("`@(",@;F]W(&QE
M="=S('1R>2!G971T:6YG(&AE;'!E<B!M;V1U;&5S(&9R;VT@=VET:&EN"B`@
M("!R97%U:7)E($E/.CI&:6QE.PH*("`@(",@;&]A9"!R97-T(&]F('1H92!G
M<F]U<"!I;@H@("`@=VAI;&4@*&UY("1F:6QE;F%M92`]("AS;W)T(&ME>7,@
M)7)E<75I<F5?;&ES="E;,%TI('L*("`@("`@("`C;&]C86P@)$E.0WLG0W=D
M+G!M)WT@/2!?7T9)3$5?7R!I9B`D7D\@;F4@)TU35VEN,S(G.PH@("`@("`@
M('5N;&5S<R`H)$E.0WLD9FEL96YA;65](&]R("1F:6QE;F%M92`]?B`O0E-$
M4$%.+RD@>PH@("`@("`@("`@("`C(')E<75I<F4@;6]D=6QE<RP@9&\@;W1H
M97(@97AE8W5T86)L92!F:6QE<PH@("`@("`@("`@("!I9B`H)&9I;&5N86UE
M(#U^("]<+G!M8S\D+VDI('L*("`@("`@("`@("`@("`@(')E<75I<F4@)&9I
M;&5N86UE.PH@("`@("`@("`@("!]"B`@("`@("`@("`@(&5L<V4@>PH@("`@
M("`@("`@("`@("`@(R!3:VEP($%C=&EV95-T871E)W,@<VET96-U<W1O;6EZ
M92YP;"!F:6QE.@H@("`@("`@("`@("`@("`@9&\@)&9I;&5N86UE('5N;&5S
M<R`D9FEL96YA;64@/7X@+W-I=&5C=7-T;VUI>F5<+G!L)"\["B`@("`@("`@
M("`@('T*("`@("`@("!]"B`@("`@("`@9&5L971E("1R97%U:7)E7VQI<W1[
M)&9I;&5N86UE?3L*("`@('T*"B`@("`C('U]?0H*("`@(&QA<W0@=6YL97-S
M("1B=68@97$@(E!+7#`P,UPP,#0B.PH@("`@)'-T87)T7W!O<R`]("AT96QL
M(%]&2"D@+2`T.PI]"B,@?7U]"@HC($%R9W5M96YT('!R;V-E<W-I;F<@>WM[
M"FUY($!P87)?87)G<SL*;7D@*"1O=70L("1B=6YD;&4L("1L;V=F:"P@)&-A
M8VAE7VYA;64I.PH*9&5L971E("1%3E9[4$%27T%04%]2155317T[(",@<V%N
M:71I>F4@*%)%55-%(&UA>2!B92!A('-E8W5R:71Y('!R;V)L96TI"@HD<75I
M970@/2`P('5N;&5S<R`D14Y6>U!!4E]$14)51WT["B,@1&]N)W0@<W=A;&QO
M=R!A<F=U;65N=',@9F]R(&-O;7!I;&5D(&5X96-U=&%B;&5S('=I=&AO=70@
M+2UP87(M;W!T:6]N<PII9B`H(21S=&%R=%]P;W,@;W(@*"1!4D=66S!=(&5Q
M("<M+7!A<BUO<'1I;VYS)R`F)B!S:&EF="DI('L*("`@(&UY("5D:7-T7V-M
M9"`]('%W*`H@("`@("`@('`@("!B;&EB7W1O7W!A<@H@("`@("`@(&D@("!I
M;G-T86QL7W!A<@H@("`@("`@('4@("!U;FEN<W1A;&Q?<&%R"B`@("`@("`@
M<R`@('-I9VY?<&%R"B`@("`@("`@=B`@('9E<FEF>5]P87(*("`@("D["@H@
M("`@(R!I9B!T:&4@87!P(&ES(&EN=F]K960@87,@(F%P<&YA;64@+2UP87(M
M;W!T:6]N<R`M+7)E=7-E(%!23T=204T@0%!23T=?05)'5B(L"B`@("`C('5S
M92!T:&4@87!P('1O(')U;B!T:&4@9VEV96X@<&5R;"!C;V1E(&EN<W1E860@
M;V8@86YY=&AI;F<@9G)O;2!T:&4*("`@(",@87!P(&ET<V5L9B`H8G5T('-T
M:6QL('-E="!U<"!T:&4@;F]R;6%L(&%P<"!E;G9I<F]N;65N="!A;F0@0$E.
M0RD*("`@(&EF("A`05)'5B!A;F0@)$%21U9;,%T@97$@)RTM<F5U<V4G*2![
M"B`@("`@("`@<VAI9G0@0$%21U8["B`@("`@("`@)$5.5GM005)?05!07U)%
M55-%?2`]('-H:69T($!!4D=6.PH@("`@?0H@("`@96QS92![(",@;F]R;6%L
M('!A<FP@8F5H879I;W5R"@H@("`@("`@(&UY($!A9&1?=&]?:6YC.PH@("`@
M("`@('=H:6QE("A`05)'5BD@>PH@("`@("`@("`@("`D05)'5ELP72`]?B`O
M7BTH6T%)34]"3&)Q<&EU<U1V72DH+BHI+R!O<B!L87-T.PH*("`@("`@("`@
M("`@:68@*"0Q(&5Q("=))RD@>PH@("`@("`@("`@("`@("`@<'5S:"!`861D
M7W1O7VEN8RP@)#(["B`@("`@("`@("`@('T*("`@("`@("`@("`@96QS:68@
M*"0Q(&5Q("=-)RD@>PH@("`@("`@("`@("`@("`@979A;"`B=7-E("0R(CL*
M("`@("`@("`@("`@?0H@("`@("`@("`@("!E;'-I9B`H)#$@97$@)T$G*2![
M"B`@("`@("`@("`@("`@("!U;G-H:69T($!P87)?87)G<RP@)#(["B`@("`@
M("`@("`@('T*("`@("`@("`@("`@96QS:68@*"0Q(&5Q("=/)RD@>PH@("`@
M("`@("`@("`@("`@)&]U="`]("0R.PH@("`@("`@("`@("!]"B`@("`@("`@
M("`@(&5L<VEF("@D,2!E<2`G8B<I('L*("`@("`@("`@("`@("`@("1B=6YD
M;&4@/2`G<VET92<["B`@("`@("`@("`@('T*("`@("`@("`@("`@96QS:68@
M*"0Q(&5Q("=")RD@>PH@("`@("`@("`@("`@("`@)&)U;F1L92`]("=A;&PG
M.PH@("`@("`@("`@("!]"B`@("`@("`@("`@(&5L<VEF("@D,2!E<2`G<2<I
M('L*("`@("`@("`@("`@("`@("1Q=6EE="`](#$["B`@("`@("`@("`@('T*
M("`@("`@("`@("`@96QS:68@*"0Q(&5Q("=,)RD@>PH@("`@("`@("`@("`@
M("`@;W!E;B`D;&]G9F@L("(^/B(L("0R(&]R(&1I92`B6%A8.B!#86YN;W0@
M;W!E;B!L;V<Z("0A(CL*("`@("`@("`@("`@?0H@("`@("`@("`@("!E;'-I
M9B`H)#$@97$@)U0G*2!["B`@("`@("`@("`@("`@("`D8V%C:&5?;F%M92`]
M("0R.PH@("`@("`@("`@("!]"@H@("`@("`@("`@("!S:&EF="A`05)'5BD[
M"@H@("`@("`@("`@("!I9B`H;7D@)&-M9"`]("1D:7-T7V-M9'LD,7TI('L*
M("`@("`@("`@("`@("`@(&1E;&5T92`D14Y6>R=005)?5$5-4"=].PH@("`@
M("`@("`@("`@("`@:6YI=%]I;F,H*3L*("`@("`@("`@("`@("`@(')E<75I
M<F4@4$%2.CI$:7-T.PH@("`@("`@("`@("`@("`@)GLB4$%2.CI$:7-T.CHD
M8VUD(GTH*2!U;FQE<W,@0$%21U8["B`@("`@("`@("`@("`@("`F>R)005(Z
M.D1I<W0Z.B1C;60B?2@D7RD@9F]R($!!4D=6.PH@("`@("`@("`@("`@("`@
M97AI=#L*("`@("`@("`@("`@?0H@("`@("`@('T*"B`@("`@("`@=6YS:&EF
M="!`24Y#+"!`861D7W1O7VEN8SL*("`@('T*?0H*(R!86%@@+2T@861D("TM
M<&%R+61E8G5G('-U<'!O<G0A"@HC('U]?0H*(R!/=71P=70@;6]D92`H+4\I
M(&AA;F1L:6YG('M[>PII9B`H)&]U="D@>PH@("`@>PH@("`@("`@("-L;V-A
M;"`D24Y#>R=#=V0N<&TG?2`](%]?1DE,15]?(&EF("1>3R!N92`G35-7:6XS
M,B<["B`@("`@("`@<F5Q=6ER92!)3SHZ1FEL93L*("`@("`@("!R97%U:7)E
M($%R8VAI=F4Z.EII<#L*("`@('T*"B`@("!M>2`D<&%R(#T@<VAI9G0H0$%2
M1U8I.PH@("`@;7D@)'II<#L*"@H@("`@:68@*&1E9FEN960@)'!A<BD@>PH@
M("`@("`@(&]P96X@;7D@)&9H+"`G/"<L("1P87(@;W(@9&EE(")#86YN;W0@
M9FEN9"`G)'!A<B<Z("0A(CL*("`@("`@("!B:6YM;V1E*"1F:"D["B`@("`@
M("`@8FQE<W,H)&9H+"`G24\Z.D9I;&4G*3L*"B`@("`@("`@)'II<"`]($%R
M8VAI=F4Z.EII<"T^;F5W.PH@("`@("`@("@@)'II<"T^<F5A9$9R;VU&:6QE
M2&%N9&QE*"1F:"P@)'!A<BD@/3T@07)C:&EV93HZ6FEP.CI!6E]/2R@I("D*
M("`@("`@("`@("`@;W(@9&EE(")296%D("<D<&%R)R!E<G)O<CH@)"$B.PH@
M("`@?0H*"B`@("!M>2`E96YV(#T@9&\@>PH@("`@("`@(&EF("@D>FEP(&%N
M9"!M>2`D;65T82`]("1Z:7`M/F-O;G1E;G1S*"=-151!+GEM;"<I*2!["B`@
M("`@("`@("`@("1M971A(#U^(',O+BI><&%R.B0O+VUS.PH@("`@("`@("`@
M("`D;65T82`]?B!S+UY<4RXJ+R]M<SL*("`@("`@("`@("`@)&UE=&$@/7X@
M+UX@("A;7CI=*RDZ("@N*RDD+VUG.PH@("`@("`@('T*("`@('T["@H@("`@
M(R!/<&5N(&EN<'5T(&%N9"!O=71P=70@9FEL97,@>WM["B`@("!L;V-A;"`D
M+R`](%PT.PH*("`@(&EF("AD969I;F5D("1P87(I('L*("`@("`@("!O<&5N
M(%!!4BP@)SPG+"`D<&%R(&]R(&1I92`B)"$Z("1P87(B.PH@("`@("`@(&)I
M;FUO9&4H4$%2*3L*("`@("`@("!D:64@(B1P87(@:7,@;F]T(&$@4$%2(&9I
M;&4B('5N;&5S<R`\4$%2/B!E<2`B4$M<,#`S7#`P-"(["B`@("!]"@H@("`@
M0W)E871E4&%T:"@D;W5T*2`["B`@("`*("`@(&UY("1F:"`]($E/.CI&:6QE
M+3YN97<H"B`@("`@("`@)&]U="P*("`@("`@("!)3SHZ1FEL93HZ3U]#4D5!
M5"@I('P@24\Z.D9I;&4Z.D]?5U)/3DQ9*"D@?"!)3SHZ1FEL93HZ3U]44E5.
M0R@I+`H@("`@("`@(#`W-S<L"B`@("`I(&]R(&1I92`D(3L*("`@(&)I;FUO
M9&4H)&9H*3L*"B`@("`D+R`]("AD969I;F5D("1D871A7W!O<RD@/R!<)&1A
M=&%?<&]S(#H@=6YD968["B`@("!S965K(%]&2"P@,"P@,#L*("`@(&UY("1L
M;V%D97(@/2!S8V%L87(@/%]&2#X["B`@("!I9B`H(21%3E9[4$%27U9%4D)!
M5$E-?2!A;F0@)&QO861E<B`]?B`O7B@_.B,A?%Q`<F5M*2\I('L*("`@("`@
M("!R97%U:7)E(%!!4CHZ1FEL=&5R.CI0;V13=')I<#L*("`@("`@("!005(Z
M.D9I;'1E<CHZ4&]D4W1R:7`M/FYE=RT^87!P;'DH7"1L;V%D97(L("0P*0H@
M("`@?0H@("`@9F]R96%C:"!M>2`D:V5Y("AS;W)T(&ME>7,@)65N=BD@>PH@
M("`@("`@(&UY("1V86P@/2`D96YV>R1K97E](&]R(&YE>'0["B`@("`@("`@
M)'9A;"`](&5V86P@)'9A;"!I9B`D=F%L(#U^("]>6R<B72\["B`@("`@("`@
M;7D@)&UA9VEC(#T@(E]?14Y67U!!4E\B("X@=6,H)&ME>2D@+B`B7U\B.PH@
M("`@("`@(&UY("1S970@/2`B4$%27R(@+B!U8R@D:V5Y*2`N("(])'9A;"([
M"B`@("`@("`@)&QO861E<B`]?B!S>R1M86=I8R@@*RE]>PH@("`@("`@("`@
M("`D;6%G:6,@+B`D<V5T("X@*"<@)R!X("AL96YG=&@H)#$I("T@;&5N9W1H
M*"1S970I*2D*("`@("`@("!]96<["B`@("!]"B`@("`D9F@M/G!R:6YT*"1L
M;V%D97(I.PH@("`@)"\@/2!U;F1E9CL*("`@(",@?7U]"@H@("`@(R!7<FET
M92!B=6YD;&5D(&UO9'5L97,@>WM["B`@("!I9B`H)&)U;F1L92D@>PH@("`@
M("`@(')E<75I<F4@4$%2.CI(96%V>3L*("`@("`@("!005(Z.DAE879Y.CI?
M:6YI=%]D>6YA;&]A9&5R*"D["B`@("`@("`@:6YI=%]I;F,H*3L*"B`@("`@
M("`@<F5Q=6ER95]M;V1U;&5S*"D["@H@("`@("`@(&UY($!I;F,@/2!S;W)T
M('L*("`@("`@("`@("`@;&5N9W1H*"1B*2`\/3X@;&5N9W1H*"1A*0H@("`@
M("`@('T@9W)E<"!["B`@("`@("`@("`@("$O0E-$4$%.+PH@("`@("`@('T@
M9W)E<"!["B`@("`@("`@("`@("@D8G5N9&QE(&YE("=S:71E)RD@;W(*("`@
M("`@("`@("`@*"1?(&YE("1#;VYF:6<Z.D-O;F9I9WMA<F-H;&EB97AP?2!A
M;F0*("`@("`@("`@("`@("1?(&YE("1#;VYF:6<Z.D-O;F9I9WMP<FEV;&EB
M97AP?2D["B`@("`@("`@?2!`24Y#.PH*("`@("`@("`C($9I;&4@97AI<W1S
M('1E<W0@861D960@=&\@9FEX(%)4(",T,3<Y,#H*("`@("`@("`C($9U;FYY
M+"!N;VXM97AI<W1I;F<@96YT<GD@:6X@7SPN+BXN875T;R]#;VUP<F5S<R]2
M87<O6FQI8B]A=71O<W!L:70N:7@N"B`@("`@("`@(R!4:&ES(&ES(&$@8F%N
M9"UA:60@9FEX('=I=&@@;F\@9&5E<&5R(&=R87-P(&]F('1H92!I<W-U92X*
M("`@("`@("`C(%-O;65B;V1Y('!L96%S92!G;R!T:')O=6=H('1H92!P86EN
M(&]F('5N9&5R<W1A;F1I;F<@=VAA="=S(&AA<'!E;FEN9RP*("`@("`@("`C
M($D@9F%I;&5D+B`M+2!3=&5F9F5N"B`@("`@("`@;7D@)69I;&5S.PH@("`@
M("`@("]>7SPH+BLI)"\@86YD("UE("0Q(&%N9"`D9FEL97-[)#%]*RL@9F]R
M(&ME>7,@)3HZ.PH@("`@("`@("1F:6QE<WLD7WTK*R!F;W(@=F%L=65S("5)
M3D,["@H@("`@("`@(&UY("1L:6)?97AT(#T@)$-O;F9I9SHZ0V]N9FEG>VQI
M8E]E>'1].PH@("`@("`@(&UY("5W<FET=&5N.PH*("`@("`@("!F;W)E86-H
M("AS;W)T(&ME>7,@)69I;&5S*2!["B`@("`@("`@("`@(&UY("@D;F%M92P@
M)&9I;&4I.PH*("`@("`@("`@("`@9F]R96%C:"!M>2`D9&ER("A`:6YC*2![
M"B`@("`@("`@("`@("`@("!I9B`H)&YA;64@/2`D4$%2.CI(96%V>3HZ1G5L
M;$-A8VAE>R1??2D@>PH@("`@("`@("`@("`@("`@("`@("1F:6QE(#T@)%\[
M"B`@("`@("`@("`@("`@("`@("`@;&%S=#L*("`@("`@("`@("`@("`@('T*
M("`@("`@("`@("`@("`@(&5L<VEF("@O7BA<421D:7)<15PO*"XJ6UY#8UTI
M*5Q:+VDI('L*("`@("`@("`@("`@("`@("`@("`H)&9I;&4L("1N86UE*2`]
M("@D,2P@)#(I.PH@("`@("`@("`@("`@("`@("`@(&QA<W0["B`@("`@("`@
M("`@("`@("!]"B`@("`@("`@("`@("`@("!E;'-I9B`H;2%>+VQO861E<B];
M7B]=*R\H+BI;7D-C72E<6B$I('L*("`@("`@("`@("`@("`@("`@("!I9B`H
M;7D@)')E9B`]("1005(Z.DAE879Y.CI-;V1U;&5#86-H97LD,7TI('L*("`@
M("`@("`@("`@("`@("`@("`@("`@*"1F:6QE+"`D;F%M92D@/2`H)')E9BP@
M)#$I.PH@("`@("`@("`@("`@("`@("`@("`@("!L87-T.PH@("`@("`@("`@
M("`@("`@("`@('T*("`@("`@("`@("`@("`@("`@("!E;'-I9B`H+68@(B1D
M:7(O)#$B*2!["B`@("`@("`@("`@("`@("`@("`@("`@("@D9FEL92P@)&YA
M;64I(#T@*"(D9&ER+R0Q(BP@)#$I.PH@("`@("`@("`@("`@("`@("`@("`@
M("!L87-T.PH@("`@("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@("`@
M('T*("`@("`@("`@("`@?0H*("`@("`@("`@("`@;F5X="!U;FQE<W,@9&5F
M:6YE9"`D;F%M92!A;F0@;F]T("1W<FET=&5N>R1N86UE?2LK.PH@("`@("`@
M("`@("!N97AT(&EF("%R968H)&9I;&4I(&%N9"`D9FEL92`]?B`O7"Y<421L
M:6)?97AT7$4D+SL*("`@("`@("`@("`@;W5T<R@@:F]I;B`B(BP*("`@("`@
M("`@("`@("`@('%Q*%!A8VMI;F<@(BDL(')E9B`D9FEL92`_("1F:6QE+3Y[
M;F%M97T@.B`D9FEL92P*("`@("`@("`@("`@("`@('%Q*"(N+BXI"B`@("`@
M("`@("`@("D["@H@("`@("`@("`@("!M>2`D8V]N=&5N=#L*("`@("`@("`@
M("`@:68@*')E9B@D9FEL92DI('L*("`@("`@("`@("`@("`@("1C;VYT96YT
M(#T@)&9I;&4M/GMB=69].PH@("`@("`@("`@("!]"B`@("`@("`@("`@(&5L
M<V4@>PH@("`@("`@("`@("`@("`@;W!E;B!&24Q%+"`G/"<L("1F:6QE(&]R
M(&1I92`B0V%N)W0@;W!E;B`D9FEL93H@)"$B.PH@("`@("`@("`@("`@("`@
M8FEN;6]D92A&24Q%*3L*("`@("`@("`@("`@("`@("1C;VYT96YT(#T@/$9)
M3$4^.PH@("`@("`@("`@("`@("`@8VQO<V4@1DE,13L*"B`@("`@("`@("`@
M("`@("!005(Z.D9I;'1E<CHZ4&]D4W1R:7`M/FYE=RT^87!P;'DH7"1C;VYT
M96YT+"`D9FEL92D*("`@("`@("`@("`@("`@("`@("!I9B`A)$5.5GM005)?
M5D520D%424U](&%N9"`D;F%M92`]?B`O7"XH/SIP;7QI>'QA;"DD+VD["@H@
M("`@("`@("`@("`@("`@(R!$;R!N;W0@;&5T(%A33&]A9&5R('!I8VL@=7`@
M875T;R\J(&9R;VT@96YV:7)O;FUE;G0*("`@("`@("`@("`@("`@("1C;VYT
M96YT(#U^(',O9V]T;R`K<F5T<GD@*W5N;&5S<R`K+BHO9V]T;R!R971R>3LO
M"B`@("`@("`@("`@("`@("`@("`@:68@;&,H)&YA;64I(&5Q(&QC*")84TQO
M861E<BYP;2(I.PH@("`@("`@("`@("!]"@H@("`@("`@("`@("!O=71S*'%Q
M*%=R:71T96X@87,@(B1N86UE(BDI.PH@("`@("`@("`@("`D9F@M/G!R:6YT
M*")&24Q%(BD["B`@("`@("`@("`@("1F:"T^<')I;G0H<&%C:R@G3B<L(&QE
M;F=T:"@D;F%M92D@*R`Y*2D["B`@("`@("`@("`@("1F:"T^<')I;G0H<W!R
M:6YT9B@*("`@("`@("`@("`@("`@("(E,#AX+R5S(BP@07)C:&EV93HZ6FEP
M.CIC;VUP=71E0U)#,S(H)&-O;G1E;G0I+"`D;F%M90H@("`@("`@("`@("`I
M*3L*("`@("`@("`@("`@)&9H+3YP<FEN="AP86-K*"=.)RP@;&5N9W1H*"1C
M;VYT96YT*2DI.PH@("`@("`@("`@("`D9F@M/G!R:6YT*"1C;VYT96YT*3L*
M("`@("`@("!]"B`@("!]"B`@("`C('U]?0H*("`@(",@3F]W('=R:71E(&]U
M="!T:&4@4$%2(&%N9"!M86=I8R!S=')I;F=S('M[>PH@("`@)'II<"T^=W)I
M=&54;T9I;&5(86YD;&4H)&9H*2!I9B`D>FEP.PH*("`@("1C86-H95]N86UE
M(#T@<W5B<W1R("1C86-H95]N86UE+"`P+"`T,#L*("`@(&EF("@A)&-A8VAE
M7VYA;64@86YD(&UY("1M=&EM92`]("AS=&%T*"1O=70I*5LY72D@>PH@("`@
M("`@(&UY("1C='@@/2!E=F%L('L@<F5Q=6ER92!$:6=E<W0Z.E-(03L@1&EG
M97-T.CI32$$M/FYE=R@Q*2!]"B`@("`@("`@("`@('Q\(&5V86P@>R!R97%U
M:7)E($1I9V5S=#HZ4TA!,3L@1&EG97-T.CI32$$Q+3YN97<@?0H@("`@("`@
M("`@("!\?"!E=F%L('L@<F5Q=6ER92!$:6=E<W0Z.DU$-3L@1&EG97-T.CI-
M1#4M/FYE=R!].PH*("`@("`@("`C(%=O<FMA<F]U;F0@9F]R(&)U9R!I;B!$
M:6=E<W0Z.E-(02`U+C,X(&%N9"`U+C,Y"B`@("`@("`@;7D@)'-H85]V97)S
M:6]N(#T@979A;"![("1$:6=E<W0Z.E-(03HZ5D524TE/3B!]('Q\(#`["B`@
M("`@("`@:68@*"1S:&%?=F5R<VEO;B!E<2`G-2XS."<@;W(@)'-H85]V97)S
M:6]N(&5Q("<U+C,Y)RD@>PH@("`@("`@("`@("`D8W1X+3YA9&1F:6QE*"1O
M=70L(")B(BD@:68@*"1C='@I.PH@("`@("`@('T*("`@("`@("!E;'-E('L*
M("`@("`@("`@("`@:68@*"1C='@@86YD(&]P96XH;7D@)&9H+"`B/"1O=70B
M*2D@>PH@("`@("`@("`@("`@("`@8FEN;6]D92@D9F@I.PH@("`@("`@("`@
M("`@("`@)&-T>"T^861D9FEL92@D9F@I.PH@("`@("`@("`@("`@("`@8VQO
M<V4H)&9H*3L*("`@("`@("`@("`@?0H@("`@("`@('T*"B`@("`@("`@)&-A
M8VAE7VYA;64@/2`D8W1X(#\@)&-T>"T^:&5X9&EG97-T(#H@)&UT:6UE.PH@
M("`@?0H@("`@)&-A8VAE7VYA;64@+CT@(EPP(B!X("@T,2`M(&QE;F=T:"`D
M8V%C:&5?;F%M92D["B`@("`D8V%C:&5?;F%M92`N/2`B0T%#2$4B.PH@("`@
M)&9H+3YP<FEN="@D8V%C:&5?;F%M92D["B`@("`D9F@M/G!R:6YT*'!A8VLH
M)TXG+"`D9F@M/G1E;&P@+2!L96YG=&@H)&QO861E<BDI*3L*("`@("1F:"T^
M<')I;G0H(EQN4$%2+G!M7&XB*3L*("`@("1F:"T^8VQO<V4["B`@("!C:&UO
M9"`P-S4U+"`D;W5T.PH@("`@(R!]?7T*"B`@("!E>&ET.PI]"B,@?7U]"@HC
M(%!R97!A<F4@)'!R;V=N86UE(&EN=&\@4$%2(&9I;&4@8V%C:&4@>WM["GL*
M("`@(&QA<W0@=6YL97-S(&1E9FEN960@)'-T87)T7W!O<SL*"B`@("!?9FEX
M7W!R;V=N86UE*"D["@H@("`@(R!.;W<@;&]A9"!T:&4@4$%2(&9I;&4@86YD
M('!U="!I="!I;G1O(%!!4CHZ3&EB0V%C:&4@>WM["B`@("!R97%U:7)E(%!!
M4CL*("`@(%!!4CHZ2&5A=GDZ.E]I;FET7V1Y;F%L;V%D97(H*3L*"@H@("`@
M>PH@("`@("`@("-L;V-A;"`D24Y#>R=#=V0N<&TG?2`](%]?1DE,15]?(&EF
M("1>3R!N92`G35-7:6XS,B<["B`@("`@("`@<F5Q=6ER92!&:6QE.CI&:6YD
M.PH@("`@("`@(')E<75I<F4@07)C:&EV93HZ6FEP.PH@("`@?0H@("`@;7D@
M)'II<"`]($%R8VAI=F4Z.EII<"T^;F5W.PH@("`@;7D@)&9H(#T@24\Z.D9I
M;&4M/FYE=SL*("`@("1F:"T^9F1O<&5N*&9I;&5N;RA?1D@I+"`G<B<I(&]R
M(&1I92`B)"$Z("1`(CL*("`@("1Z:7`M/G)E861&<F]M1FEL94AA;F1L92@D
M9F@L("1P<F]G;F%M92D@/3T@07)C:&EV93HZ6FEP.CI!6E]/2R@I(&]R(&1I
M92`B)"$Z("1`(CL*"B`@("!P=7-H($!005(Z.DQI8D-A8VAE+"`D>FEP.PH@
M("`@)%!!4CHZ3&EB0V%C:&5[)'!R;V=N86UE?2`]("1Z:7`["@H@("`@)'%U
M:65T(#T@(21%3E9[4$%27T1%0E5'?3L*("`@(&]U=',H<7$H7"1%3E9[4$%2
M7U1%35!](#T@(B1%3E9[4$%27U1%35!](BDI.PH*("`@(&EF("AD969I;F5D
M("1%3E9[4$%27U1%35!]*2![(",@<VAO=6QD(&)E('-E="!A="!T:&ES('!O
M:6YT(0H@("`@("`@(&9O<F5A8V@@;7D@)&UE;6)E<B`H("1Z:7`M/FUE;6)E
M<G,@*2!["B`@("`@("`@("`@(&YE>'0@:68@)&UE;6)E<BT^:7-$:7)E8W1O
M<GD["B`@("`@("`@("`@(&UY("1M96UB97)?;F%M92`]("1M96UB97(M/F9I
M;&5.86UE.PH@("`@("`@("`@("!N97AT('5N;&5S<R`D;65M8F5R7VYA;64@
M/7X@;7L*("`@("`@("`@("`@("`@(%X*("`@("`@("`@("`@("`@("\_<VAL
M:6(O"B`@("`@("`@("`@("`@("`H/SHD0V]N9FEG.CI#;VYF:6=[=F5R<VEO
M;GTO*3\*("`@("`@("`@("`@("`@("@_.B1#;VYF:6<Z.D-O;F9I9WMA<F-H
M;F%M97TO*3\*("`@("`@("`@("`@("`@("A;7B]=*RD*("`@("`@("`@("`@
M("`@("0*("`@("`@("`@("`@?7@["B`@("`@("`@("`@(&UY("1E>'1R86-T
M7VYA;64@/2`D,3L*("`@("`@("`@("`@;7D@)&1E<W1?;F%M92`]($9I;&4Z
M.E-P96,M/F-A=&9I;&4H)$5.5GM005)?5$5-4'TL("1E>'1R86-T7VYA;64I
M.PH@("`@("`@("`@("!I9B`H+68@)&1E<W1?;F%M92`F)B`M<R!?(#T]("1M
M96UB97(M/G5N8V]M<')E<W-E9%-I>F4H*2D@>PH@("`@("`@("`@("`@("`@
M;W5T<RAQ<2A3:VEP<&EN9R`B)&UE;6)E<E]N86UE(B!S:6YC92!I="!A;')E
M861Y(&5X:7-T<R!A="`B)&1E<W1?;F%M92(I*3L*("`@("`@("`@("`@?2!E
M;'-E('L*("`@("`@("`@("`@("`@(&]U=',H<7$H17AT<F%C=&EN9R`B)&UE
M;6)E<E]N86UE(B!T;R`B)&1E<W1?;F%M92(I*3L*("`@("`@("`@("`@("`@
M("1M96UB97(M/F5X=')A8W14;T9I;&5.86UE9"@D9&5S=%]N86UE*3L*("`@
M("`@("`@("`@("`@(&-H;6]D*#`U-34L("1D97-T7VYA;64I(&EF("1>3R!E
M<2`B:'!U>"(["B`@("`@("`@("`@('T*("`@("`@("!]"B`@("!]"B`@("`C
M('U]?0I]"B,@?7U]"@HC($EF('1H97)E)W,@;F\@;6%I;BYP;"!T;R!R=6XL
M('-H;W<@=7-A9V4@>WM["G5N;&5S<R`H)%!!4CHZ3&EB0V%C:&5[)'!R;V=N
M86UE?2D@>PH@("`@9&EE(#P\("(N(B!U;FQE<W,@0$%21U8["E5S86=E.B`D
M,"!;("U!;&EB+G!A<B!=(%L@+4ED:7(@72!;("U-;6]D=6QE(%T@6R!S<F,N
M<&%R(%T@6R!P<F]G<F%M+G!L(%T*("`@("`@("0P(%L@+4)\+6(@72!;+4]O
M=71F:6QE72!S<F,N<&%R"BX*("`@("1%3E9[4$%27U!23T=.04U%?2`]("1P
M<F]G;F%M92`]("0P(#T@<VAI9G0H0$%21U8I.PI]"B,@?7U]"@IS=6(@0W)E
M871E4&%T:"!["B`@("!M>2`H)&YA;64I(#T@0%\["B`@("`*("`@(')E<75I
M<F4@1FEL93HZ0F%S96YA;64["B`@("!M>2`H)&)A<V5N86UE+"`D<&%T:"P@
M)&5X="D@/2!&:6QE.CI"87-E;F%M93HZ9FEL97!A<G-E*"1N86UE+"`H)UPN
M+BHG*2D["B`@("`*("`@(')E<75I<F4@1FEL93HZ4&%T:#L*("`@(`H@("`@
M1FEL93HZ4&%T:#HZ;6MP871H*"1P871H*2!U;FQE<W,H+64@)'!A=&@I.R`C
M(&UK<&%T:"!D:65S('=I=&@@97)R;W(*?0H*<W5B(')E<75I<F5?;6]D=6QE
M<R!["B`@("`C;&]C86P@)$E.0WLG0W=D+G!M)WT@/2!?7T9)3$5?7R!I9B`D
M7D\@;F4@)TU35VEN,S(G.PH*("`@(')E<75I<F4@;&EB.PH@("`@<F5Q=6ER
M92!$>6YA3&]A9&5R.PH@("`@<F5Q=6ER92!I;G1E9V5R.PH@("`@<F5Q=6ER
M92!S=')I8W0["B`@("!R97%U:7)E('=A<FYI;F=S.PH@("`@<F5Q=6ER92!V
M87)S.PH@("`@<F5Q=6ER92!#87)P.PH@("`@<F5Q=6ER92!#87)P.CI(96%V
M>3L*("`@(')E<75I<F4@17)R;F\["B`@("!R97%U:7)E($5X<&]R=&5R.CI(
M96%V>3L*("`@(')E<75I<F4@17AP;W)T97(["B`@("!R97%U:7)E($9C;G1L
M.PH@("`@<F5Q=6ER92!&:6QE.CI496UP.PH@("`@<F5Q=6ER92!&:6QE.CI3
M<&5C.PH@("`@<F5Q=6ER92!84TQO861E<CL*("`@(')E<75I<F4@0V]N9FEG
M.PH@("`@<F5Q=6ER92!)3SHZ2&%N9&QE.PH@("`@<F5Q=6ER92!)3SHZ1FEL
M93L*("`@(')E<75I<F4@0V]M<')E<W,Z.EIL:6(["B`@("!R97%U:7)E($%R
M8VAI=F4Z.EII<#L*("`@(')E<75I<F4@4$%2.PH@("`@<F5Q=6ER92!005(Z
M.DAE879Y.PH@("`@<F5Q=6ER92!005(Z.D1I<W0["B`@("!R97%U:7)E(%!!
M4CHZ1FEL=&5R.CI0;V13=')I<#L*("`@(')E<75I<F4@871T<FEB=71E<SL*
M("`@(&5V86P@>R!R97%U:7)E($-W9"!].PH@("`@979A;"![(')E<75I<F4@
M5VEN,S(@?3L*("`@(&5V86P@>R!R97%U:7)E(%-C86QA<CHZ571I;"!].PH@
M("`@979A;"![(')E<75I<F4@07)C:&EV93HZ56YZ:7`Z.D)U<G-T('T["B`@
M("!E=F%L('L@<F5Q=6ER92!4:64Z.DAA<V@Z.DYA;65D0V%P='5R92!].PH@
M("`@979A;"![(')E<75I<F4@4&5R;$E/.R!R97%U:7)E(%!E<FQ)3SHZ<V-A
M;&%R('T["GT*"B,@5&AE($,@=F5R<VEO;B!O9B!T:&ES(&-O9&4@87!P96%R
M<R!I;B!M>6QD<B]M:W1M<&1I<BYC"B,@5&AI<R!C;V1E(&%L<V\@;&EV97,@
M:6X@4$%2.CI3971U<%1E;7`@87,@<V5T7W!A<E]T96UP7V5N=B$*<W5B(%]S
M971?<&%R7W1E;7`@>PH@("`@:68@*&1E9FEN960@)$5.5GM005)?5$5-4'T@
M86YD("1%3E9[4$%27U1%35!](#U^("\H+BLI+RD@>PH@("`@("`@("1P87)?
M=&5M<"`]("0Q.PH@("`@("`@(')E='5R;CL*("`@('T*"B`@("!F;W)E86-H
M(&UY("1P871H("@*("`@("`@("`H;6%P("1%3E9[)%]]+"!Q=R@@4$%27U1-
M4$1)4B!435!$25(@5$5-4$1)4B!414U0(%1-4"`I*2P*("`@("`@("!Q=R@@
M0SI<7%1%35`@+W1M<"`N("D*("`@("D@>PH@("`@("`@(&YE>'0@=6YL97-S
M(&1E9FEN960@)'!A=&@@86YD("UD("1P871H(&%N9"`M=R`D<&%T:#L*("`@
M("`@("!M>2`D=7-E<FYA;64["B`@("`@("`@;7D@)'!W=6ED.PH@("`@("`@
M(",@9&]E<R!N;W0@=V]R:R!E=F5R>7=H97)E.@H@("`@("`@(&5V86P@>R@D
M<'=U:60I(#T@9V5T<'=U:60H)#XI(&EF(&1E9FEN960@)#X[?3L*"B`@("`@
M("`@:68@*"!D969I;F5D*"97:6XS,CHZ3&]G:6Y.86UE*2`I('L*("`@("`@
M("`@("`@)'5S97)N86UE(#T@)E=I;C,R.CI,;V=I;DYA;64["B`@("`@("`@
M?0H@("`@("`@(&5L<VEF("AD969I;F5D("1P=W5I9"D@>PH@("`@("`@("`@
M("`D=7-E<FYA;64@/2`D<'=U:60["B`@("`@("`@?0H@("`@("`@(&5L<V4@
M>PH@("`@("`@("`@("`D=7-E<FYA;64@/2`D14Y6>U5315).04U%?2!\?"`D
M14Y6>U5315)]('Q\("=365-414TG.PH@("`@("`@('T*("`@("`@("`D=7-E
M<FYA;64@/7X@<R]<5R]?+V<["@H@("`@("`@(&UY("1S=&UP9&ER(#T@(B1P
M871H)$-O;F9I9WM?9&5L:6U]<&%R+21U<V5R;F%M92(["B`@("`@("`@;6MD
M:7(@)'-T;7!D:7(L(#`W-34["B`@("`@("`@:68@*"$D14Y6>U!!4E]#3$5!
M3GT@86YD(&UY("1M=&EM92`]("AS=&%T*"1P<F]G;F%M92DI6SE=*2!["B`@
M("`@("`@("`@(&]P96X@*&UY("1F:"P@(CPB+B`D<')O9VYA;64I.PH@("`@
M("`@("`@("!S965K("1F:"P@+3$X+"`R.PH@("`@("`@("`@("!S>7-R96%D
M("1F:"P@;7D@)&)U9BP@-CL*("`@("`@("`@("`@:68@*"1B=68@97$@(EPP
M0T%#2$4B*2!["B`@("`@("`@("`@("`@("!S965K("1F:"P@+34X+"`R.PH@
M("`@("`@("`@("`@("`@<WES<F5A9"`D9F@L("1B=68L(#0Q.PH@("`@("`@
M("`@("`@("`@)&)U9B`]?B!S+UPP+R]G.PH@("`@("`@("`@("`@("`@)'-T
M;7!D:7(@+CT@(B1#;VYF:6=[7V1E;&EM?6-A8VAE+2(@+B`D8G5F.PH@("`@
M("`@("`@("!]"B`@("`@("`@("`@(&5L<V4@>PH@("`@("`@("`@("`@("`@
M;7D@)&-T>"`](&5V86P@>R!R97%U:7)E($1I9V5S=#HZ4TA!.R!$:6=E<W0Z
M.E-(02T^;F5W*#$I('T*("`@("`@("`@("`@("`@("`@("!\?"!E=F%L('L@
M<F5Q=6ER92!$:6=E<W0Z.E-(03$[($1I9V5S=#HZ4TA!,2T^;F5W('T*("`@
M("`@("`@("`@("`@("`@("!\?"!E=F%L('L@<F5Q=6ER92!$:6=E<W0Z.DU$
M-3L@1&EG97-T.CI-1#4M/FYE=R!].PH*("`@("`@("`@("`@("`@(",@5V]R
M:V%R;W5N9"!F;W(@8G5G(&EN($1I9V5S=#HZ4TA!(#4N,S@@86YD(#4N,SD*
M("`@("`@("`@("`@("`@(&UY("1S:&%?=F5R<VEO;B`](&5V86P@>R`D1&EG
M97-T.CI32$$Z.E9%4E-)3TX@?2!\?"`P.PH@("`@("`@("`@("`@("`@:68@
M*"1S:&%?=F5R<VEO;B!E<2`G-2XS."<@;W(@)'-H85]V97)S:6]N(&5Q("<U
M+C,Y)RD@>PH@("`@("`@("`@("`@("`@("`@("1C='@M/F%D9&9I;&4H)'!R
M;V=N86UE+"`B8B(I(&EF("@D8W1X*3L*("`@("`@("`@("`@("`@('T*("`@
M("`@("`@("`@("`@(&5L<V4@>PH@("`@("`@("`@("`@("`@("`@(&EF("@D
M8W1X(&%N9"!O<&5N*&UY("1F:"P@(CPD<')O9VYA;64B*2D@>PH@("`@("`@
M("`@("`@("`@("`@("`@("!B:6YM;V1E*"1F:"D["B`@("`@("`@("`@("`@
M("`@("`@("`@("1C='@M/F%D9&9I;&4H)&9H*3L*("`@("`@("`@("`@("`@
M("`@("`@("`@8VQO<V4H)&9H*3L*("`@("`@("`@("`@("`@("`@("!]"B`@
M("`@("`@("`@("`@("!]"@H@("`@("`@("`@("`@("`@)'-T;7!D:7(@+CT@
M(B1#;VYF:6=[7V1E;&EM?6-A8VAE+2(@+B`H("1C='@@/R`D8W1X+3YH97AD
M:6=E<W0@.B`D;71I;64@*3L*("`@("`@("`@("`@?0H@("`@("`@("`@("!C
M;&]S92@D9F@I.PH@("`@("`@('T*("`@("`@("!E;'-E('L*("`@("`@("`@
M("`@)$5.5GM005)?0TQ%04Y](#T@,3L*("`@("`@("`@("`@)'-T;7!D:7(@
M+CT@(B1#;VYF:6=[7V1E;&EM?71E;7`M)"0B.PH@("`@("`@('T*"B`@("`@
M("`@)$5.5GM005)?5$5-4'T@/2`D<W1M<&1I<CL*("`@("`@("!M:V1I<B`D
M<W1M<&1I<BP@,#<U-3L*("`@("`@("!L87-T.PH@("`@?0H*("`@("1P87)?
M=&5M<"`]("0Q(&EF("1%3E9[4$%27U1%35!](&%N9"`D14Y6>U!!4E]414U0
M?2`]?B`O*"XK*2\["GT*"G-U8B!?=&5M<&9I;&4@>PH@("`@;7D@*"1E>'0L
M("1C<F,I(#T@0%\["B`@("!M>2`H)&9H+"`D9FEL96YA;64I.PH*("`@("1F
M:6QE;F%M92`]("(D<&%R7W1E;7`O)&-R8R1E>'0B.PH*("`@(&EF("@D14Y6
M>U!!4E]#3$5!3GTI('L*("`@("`@("!U;FQI;FL@)&9I;&5N86UE(&EF("UE
M("1F:6QE;F%M93L*("`@("`@("!P=7-H($!T;7!F:6QE+"`D9FEL96YA;64[
M"B`@("!]"B`@("!E;'-E('L*("`@("`@("!R971U<FX@*'5N9&5F+"`D9FEL
M96YA;64I(&EF("@M<B`D9FEL96YA;64I.PH@("`@?0H*("`@(&]P96X@)&9H
M+"`G/B<L("1F:6QE;F%M92!O<B!D:64@)"$["B`@("!B:6YM;V1E*"1F:"D[
M"B`@("!R971U<FXH)&9H+"`D9FEL96YA;64I.PI]"@HC('-A;64@8V]D92!L
M:79E<R!I;B!005(Z.E-E='5P4')O9VYA;64Z.G-E=%]P<F]G;F%M90IS=6(@
M7W-E=%]P<F]G;F%M92!["B`@("!I9B`H9&5F:6YE9"`D14Y6>U!!4E]04D]'
M3D%-17T@86YD("1%3E9[4$%27U!23T=.04U%?2`]?B`O*"XK*2\I('L*("`@
M("`@("`D<')O9VYA;64@/2`D,3L*("`@('T*"B`@("`D<')O9VYA;64@?'P]
M("0P.PH*("`@(&EF("@D14Y6>U!!4E]414U0?2!A;F0@:6YD97@H)'!R;V=N
M86UE+"`D14Y6>U!!4E]414U0?2D@/CT@,"D@>PH@("`@("`@("1P<F]G;F%M
M92`]('-U8G-T<B@D<')O9VYA;64L(')I;F1E>"@D<')O9VYA;64L("1#;VYF
M:6=[7V1E;&EM?2D@*R`Q*3L*("`@('T*"B`@("!I9B`H(21%3E9[4$%27U!2
M3T=.04U%?2!O<B!I;F1E>"@D<')O9VYA;64L("1#;VYF:6=[7V1E;&EM?2D@
M/CT@,"D@>PH@("`@("`@(&EF("AO<&5N(&UY("1F:"P@)SPG+"`D<')O9VYA
M;64I('L*("`@("`@("`@("`@<F5T=7)N(&EF("US("1F:#L*("`@("`@("!]
M"B`@("`@("`@:68@*"US("(D<')O9VYA;64D0V]N9FEG>U]E>&5](BD@>PH@
M("`@("`@("`@("`D<')O9VYA;64@+CT@)$-O;F9I9WM?97AE?3L*("`@("`@
M("`@("`@<F5T=7)N.PH@("`@("`@('T*("`@('T*"B`@("!F;W)E86-H(&UY
M("1D:7(@*'-P;&ET("]<421#;VYF:6=[<&%T:%]S97!]7$4O+"`D14Y6>U!!
M5$A]*2!["B`@("`@("`@;F5X="!I9B!E>&ES=',@)$5.5GM005)?5$5-4'T@
M86YD("1D:7(@97$@)$5.5GM005)?5$5-4'T["B`@("`@("`@)&1I<B`]?B!S
M+UQ1)$-O;F9I9WM?9&5L:6U]7$4D+R\["B`@("`@("`@*"@D<')O9VYA;64@
M/2`B)&1I<B1#;VYF:6=[7V1E;&EM?21P<F]G;F%M921#;VYF:6=[7V5X97TB
M*2P@;&%S="D*("`@("`@("`@("`@:68@+7,@(B1D:7(D0V]N9FEG>U]D96QI
M;7TD<')O9VYA;64D0V]N9FEG>U]E>&5](CL*("`@("`@("`H*"1P<F]G;F%M
M92`]("(D9&ER)$-O;F9I9WM?9&5L:6U])'!R;V=N86UE(BDL(&QA<W0I"B`@
M("`@("`@("`@(&EF("US("(D9&ER)$-O;F9I9WM?9&5L:6U])'!R;V=N86UE
M(CL*("`@('T*?0H*<W5B(%]F:7A?<')O9VYA;64@>PH@("`@)#`@/2`D<')O
M9VYA;64@?'P]("1%3E9[4$%27U!23T=.04U%?3L*("`@(&EF("AI;F1E>"@D
M<')O9VYA;64L("1#;VYF:6=[7V1E;&EM?2D@/"`P*2!["B`@("`@("`@)'!R
M;V=N86UE(#T@(BXD0V]N9FEG>U]D96QI;7TD<')O9VYA;64B.PH@("`@?0H*
M("`@(",@6%A8("T@:&%C:R!T;R!M86ME(%!71"!W;W)K"B`@("!M>2`D<'=D
M(#T@*&1E9FEN960@)D-W9#HZ9V5T8W=D*2`_($-W9#HZ9V5T8W=D*"D*("`@
M("`@("`@("`@("`@(#H@*"AD969I;F5D("97:6XS,CHZ1V5T0W=D*2`_(%=I
M;C,R.CI'971#=V0H*2`Z(&!P=V1@*3L*("`@(&-H;VUP*"1P=V0I.PH@("`@
M)'!R;V=N86UE(#U^(',O7B@_/5PN7"X_7%$D0V]N9FEG>U]D96QI;7U<12DO
M)'!W9"1#;VYF:6=[7V1E;&EM?2\["@H@("`@)$5.5GM005)?4%)/1TY!345]
M(#T@)'!R;V=N86UE.PI]"@IS=6(@7W!A<E]I;FET7V5N=B!["B`@("!I9B`H
M("1%3E9[4$%27TE.251)04Q)6D5$?2LK(#T](#$@*2!["B`@("`@("`@<F5T
M=7)N.PH@("`@?2!E;'-E('L*("`@("`@("`D14Y6>U!!4E])3DE424%,25I%
M1'T@/2`R.PH@("`@?0H*("`@(&9O<B`H<7<H(%-005=.140@5$5-4"!#3$5!
M3B!$14)51R!#04-(12!04D]'3D%-12!!4D=#($%21U9?,"`I("D@>PH@("`@
M("`@(&1E;&5T92`D14Y6>R=005)?)RXD7WT["B`@("!]"B`@("!F;W(@*'%W
M+R!435!$25(@5$5-4"!#3$5!3B!$14)51R`O*2!["B`@("`@("`@)$5.5GLG
M4$%27R<N)%]](#T@)$5.5GLG4$%27T=,3T)!3%\G+B1??2!I9B!E>&ES=',@
M)$5.5GLG4$%27T=,3T)!3%\G+B1??3L*("`@('T*"B`@("!M>2`D<&%R7V-L
M96%N(#T@(E]?14Y67U!!4E]#3$5!3E]?("`@("`@("`@("`@("`@(CL*"B`@
M("!I9B`H)$5.5GM005)?5$5-4'TI('L*("`@("`@("!D96QE=&4@)$5.5GM0
M05)?0TQ%04Y].PH@("`@?0H@("`@96QS:68@*"%E>&ES=',@)$5.5GM005)?
M1TQ/0D%,7T-,14%.?2D@>PH@("`@("`@(&UY("1V86QU92`]('-U8G-T<B@D
M<&%R7V-L96%N+"`Q,B`K(&QE;F=T:"@B0TQ%04XB*2D["B`@("`@("`@)$5.
M5GM005)?0TQ%04Y](#T@)#$@:68@)'9A;'5E(#U^("]>4$%27T-,14%./2A<
M4RLI+SL*("`@('T*?0H*<W5B(&]U=',@>PH@("`@<F5T=7)N(&EF("1Q=6EE
M=#L*("`@(&EF("@D;&]G9F@I('L*("`@("`@("!P<FEN="`D;&]G9F@@(D!?
M7&XB.PH@("`@?0H@("`@96QS92!["B`@("`@("`@<')I;G0@(D!?7&XB.PH@
M("`@?0I]"@IS=6(@:6YI=%]I;F,@>PH@("`@<F5Q=6ER92!#;VYF:6<["B`@
M("!P=7-H($!)3D,L(&=R97`@9&5F:6YE9"P@;6%P("1#;VYF:6<Z.D-O;F9I
M9WLD7WTL('%W*`H@("`@("`@(&%R8VAL:6)E>'`@<')I=FQI8F5X<"!S:71E
M87)C:&5X<"!S:71E;&EB97AP"B`@("`@("`@=F5N9&]R87)C:&5X<"!V96YD
M;W)L:6)E>'`*("`@("D["GT*"B,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C
M(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C
M(PHC(%1H92!M86EN('!A8VMA9V4@9F]R('-C<FEP="!E>&5C=71I;VX*"G!A
M8VMA9V4@;6%I;CL*"G)E<75I<F4@4$%2.PIU;G-H:69T($!)3D,L(%PF4$%2
M.CIF:6YD7W!A<CL*4$%2+3YI;7!O<G0H0'!A<E]A<F=S*3L*"F1I92!Q<2AP
M87(N<&PZ($-A;B=T(&]P96X@<&5R;"!S8W)I<'0@(B1P<F]G;F%M92(Z($YO
M('-U8V@@9FEL92!O<B!D:7)E8W1O<GE<;BD*("`@('5N;&5S<R`M92`D<')O
M9VYA;64["@ID;R`D<')O9VYA;64["D-/4D4Z.F5X:70H)#$I(&EF("@D0"`]
M?B]>7U1+7T58251?7"@H7&0K*5PI+RD["F1I92`D0"!I9B`D0#L*"GT["@HD
M.CI?7T524D]2(#T@)$`@:68@)$`["GT*"D-/4D4Z.F5X:70H)#$I(&EF("@D
M.CI?7T524D]2(#U^+UY?5$M?15A)5%]<*"A<9"LI7"DO*3L*9&EE("0Z.E]?
M15)23U(@:68@)#HZ7U]%4E)/4CL*"C$["@HC;&EN92`Q,#$R"@I?7T5.1%]?
M"@```'!A<BYP;```A&O_?P$`````````8)\``$2?`````````0````$````!
M````L@(```$```"]`@```0```,<"```!````%@,```$```!1!````0```'$$
M```,````[)H```T```!,TP``&0```&2S`0`;````!````!H```!HLP$`'```
M``0````$````C($``/7^_V\(A0``!0```,"0```&`````(D```H````D!@``
M"P```!`````5``````````,```"0M`$``@```(@"```4````$0```!<```!D
MF```$0```#R8```2````*````!,````(````_O__;]R7``#___]O`P```/#_
M_V_DE@``````````````````````````````````````````````````````
M````````````<+,!````````````_)H``/R:``#\F@``_)H``/R:``#\F@``
M_)H``/R:``#\F@``_)H``/R:``#\F@``_)H``/R:``#\F@``_)H``/R:``#\
MF@``_)H``/R:``#\F@``_)H``/R:``#\F@``_)H``/R:``#\F@``_)H``/R:
M``#\F@``_)H``/R:``#\F@``_)H``/R:``#\F@``_)H``/R:``#\F@``_)H`
M`/R:``#\F@``_)H``/R:``#\F@``_)H``/R:``#\F@``_)H``/R:``#\F@``
M_)H``/R:``#\F@``_)H``/R:``#\F@``_)H``/R:``#\F@``_)H``/R:``#\
MF@``_)H``/R:``#\F@``_)H``/R:``#\F@``_)H``/R:``#\F@``_)H``/R:
M``#\F@``_)H``/R:``#\F@``_)H``/R:``#\F@``````````````````____
M_U`S`0#I6P``02L```!A96%B:0`!(0````5!4DTY5$1-20`&`@@!"0$2!!0!
M%0$7`Q@!&@)'0T,Z("A$96)I86X@-"XT+C4M."D@-"XT+C4`1T-#.B`H1&5B
M:6%N(#0N-"XU+3$P*2`T+C0N-0``+G-H<W1R=&%B`"YI;G1E<G``+FYO=&4N
M04))+71A9P`N;F]T92YG;G4N8G5I;&0M:60`+F=N=2YH87-H`"YD>6YS>6T`
M+F1Y;G-T<@`N9VYU+G9E<G-I;VX`+F=N=2YV97)S:6]N7W(`+G)E;"YD>6X`
M+G)E;"YP;'0`+FEN:70`+G1E>'0`+F9I;FD`+G)O9&%T80`N05)-+F5X:61X
M`"YE:%]F<F%M90`N:6YI=%]A<G)A>0`N9FEN:5]A<G)A>0`N:F-R`"YD>6YA
M;6EC`"YG;W0`+F1A=&$`+F)S<P`N05)-+F%T=')I8G5T97,`+F-O;6UE;G0`
M```````````````````````````````````````````````````````+````
M`0````(````T@0``-`$``!,```````````````$`````````$P````<````"
M````2($``$@!```@```````````````$`````````"$````'`````@```&B!
M``!H`0``)```````````````!``````````X````!0````(```",@0``C`$`
M`'P#```&``````````0````$````-````/;__V\"````"(4```@%``#X`P``
M!@`````````$````!````#X````+`````@````")````"0``P`<```<````!
M````!````!````!&`````P````(```#`D```P!```"0&``````````````$`
M````````3@```/___V\"````Y)8``.06``#X````!@`````````"`````@``
M`%L```#^__]O`@```-R7``#<%P``8`````<````#````!`````````!J````
M"0````(````\F```/!@``"@````&``````````0````(````<P````D````"
M````9)@``&08``"(`@``!@````T````$````"````'P````!````!@```.R:
M``#L&@``$```````````````!`````````!W`````0````8```#\F@``_!H`
M`.`#``````````````0````$````@@````$````&````W)X``-P>``!P-```
M```````````$`````````(@````!````!@```$S3``!,4P``#```````````
M````!`````````".`````0````(```!8TP``6%,```!@``````````````0`
M````````E@````$``'""````6#,!`%BS```(````#@`````````$````````
M`*$````!`````@```&`S`0!@LP``!```````````````!`````````"K````
M#@````,```!DLP$`9+,```0```````````````0`````````MP````\````#
M````:+,!`&BS```$```````````````$`````````,,````!`````P```&RS
M`0!LLP``!```````````````!`````````#(````!@````,```!PLP$`<+,`
M`"`!```'``````````0````(````T0````$````#````D+0!`)"T``!4`0``
M```````````$````!````-8````!`````P```.2U`0#DM0``%```````````
M````!`````````#<````"`````,```#XM0$`^+4``#P0``````````````@`
M````````X0````,``'```````````/BU```L```````````````!````````
M`/$````!````,``````````DM@``.0```````````````0````$````!````
M`P``````````````7;8``/H```````````````$``````````0```/R:````
M```````-``0````,FP``````````#0`!````$)L```````````T``"1A`"1D
!````
